from typing import overload
from typing import TypeVar

java_io_File = TypeVar("java_io_File")
File = java_io_File


class FileHandler_FileLineIterator(iter, AutoCloseable):

	@overload
	def __init__(self, file: File, charset: Charset) -> None:
		pass

	@overload
	def hasNext(self) -> bool:
		pass

	@overload
	def next(self) -> str:
		pass

	@overload
	def close(self) -> None:
		pass

	pass





from typing import overload
from .EventContainer import EventContainer
from .IEventListener import IEventListener


class EventLockWatchdog:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def startWatchdog(self, lock: EventContainer, listener: IEventListener, maxTime: float) -> None:
		pass

	pass





from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .LlamaEntityHelper import LlamaEntityHelper
from .MixinSpellcastingIllagerEntityHelper import MixinSpellcastingIllagerEntityHelper
from .NBTElementHelper_NBTCompoundHelper import NBTElementHelper_NBTCompoundHelper
from .ItemEntityHelper import ItemEntityHelper
from .VexEntityHelper import VexEntityHelper
from .OcelotEntityHelper import OcelotEntityHelper
from .TntEntityHelper import TntEntityHelper
from .CheckBoxWidgetHelper_CheckBoxBuilder import CheckBoxWidgetHelper_CheckBoxBuilder
from .ButtonWidgetHelper_TexturedButtonBuilder import ButtonWidgetHelper_TexturedButtonBuilder
from .TextDisplayEntityHelper import TextDisplayEntityHelper
from .DolphinEntityHelper import DolphinEntityHelper
from .ButtonWidgetHelper_ButtonBuilder import ButtonWidgetHelper_ButtonBuilder
from .StatePredicateHelper import StatePredicateHelper
from .TridentEntityHelper import TridentEntityHelper
from .PhantomEntityHelper import PhantomEntityHelper
from .EndCrystalEntityHelper import EndCrystalEntityHelper
from .PlayerEntityHelper import PlayerEntityHelper
from .VillagerEntityHelper import VillagerEntityHelper
from .TropicalFishEntityHelper import TropicalFishEntityHelper
from .FrogEntityHelper import FrogEntityHelper
from .FurnaceMinecartEntityHelper import FurnaceMinecartEntityHelper
from .ArrowEntityHelper import ArrowEntityHelper
from .BossBarHelper import BossBarHelper
from .CreeperEntityHelper import CreeperEntityHelper
from .PlayerAbilitiesHelper import PlayerAbilitiesHelper
from .LockButtonWidgetHelper import LockButtonWidgetHelper
from .SliderWidgetHelper import SliderWidgetHelper
from .GuardianEntityHelper import GuardianEntityHelper
from .CyclingButtonWidgetHelper_CyclicButtonBuilder import CyclingButtonWidgetHelper_CyclicButtonBuilder
from .WardenEntityHelper import WardenEntityHelper
from .ZombieVillagerEntityHelper import ZombieVillagerEntityHelper
from .HitResultHelper_Entity import HitResultHelper_Entity
from .MobEntityHelper import MobEntityHelper
from .AnimalEntityHelper import AnimalEntityHelper
from .ScoreboardsHelper import ScoreboardsHelper
from .EnderDragonEntityHelper import EnderDragonEntityHelper
from .OptionsHelper_VideoOptionsHelper import OptionsHelper_VideoOptionsHelper
from .OptionsHelper_ControlOptionsHelper import OptionsHelper_ControlOptionsHelper
from .BeeEntityHelper import BeeEntityHelper
from .WitchEntityHelper import WitchEntityHelper
from .DirectionHelper import DirectionHelper
from .FormattingHelper import FormattingHelper
from .FoxEntityHelper import FoxEntityHelper
from .ChatHudLineHelper import ChatHudLineHelper
from .AreaEffectCloudEntityHelper import AreaEffectCloudEntityHelper
from .FoodComponentHelper import FoodComponentHelper
from .DrownedEntityHelper import DrownedEntityHelper
from .ParrotEntityHelper import ParrotEntityHelper
from .EnchantmentHelper import EnchantmentHelper
from .SnowGolemEntityHelper import SnowGolemEntityHelper
from .ModContainerHelper import ModContainerHelper
from .HitResultHelper import HitResultHelper
from .FluidStateHelper import FluidStateHelper
from .StatsHelper import StatsHelper
from .FishingBobberEntityHelper import FishingBobberEntityHelper
from .ItemFrameEntityHelper import ItemFrameEntityHelper
from .EntityHelper import EntityHelper
from .WitherEntityHelper import WitherEntityHelper
from .CheckBoxWidgetHelper import CheckBoxWidgetHelper
from .RecipeHelper import RecipeHelper
from .ClientPlayerEntityHelper import ClientPlayerEntityHelper
from .NBTElementHelper_NBTListHelper import NBTElementHelper_NBTListHelper
from .WolfEntityHelper import WolfEntityHelper
from .OptionsHelper_MusicOptionsHelper import OptionsHelper_MusicOptionsHelper
from .MooshroomEntityHelper import MooshroomEntityHelper
from .BlockDisplayEntityHelper import BlockDisplayEntityHelper
from .ZombieEntityHelper import ZombieEntityHelper
from .PaintingEntityHelper import PaintingEntityHelper
from .BaseHelper import BaseHelper
from .GhastEntityHelper import GhastEntityHelper
from .CatEntityHelper import CatEntityHelper
from .DisplayEntityHelper import DisplayEntityHelper
from .AdvancementManagerHelper import AdvancementManagerHelper
from .ItemStackHelper import ItemStackHelper
from .CommandNodeHelper import CommandNodeHelper
from .SlimeEntityHelper import SlimeEntityHelper
from .WitherSkullEntityHelper import WitherSkullEntityHelper
from .ScoreboardObjectiveHelper import ScoreboardObjectiveHelper
from .ItemDisplayEntityHelper import ItemDisplayEntityHelper
from .BlockPredicateHelper import BlockPredicateHelper
from .PacketByteBufferHelper import PacketByteBufferHelper
from .TextFieldWidgetHelper import TextFieldWidgetHelper
from .SpellcastingIllagerEntityHelper import SpellcastingIllagerEntityHelper
from .NbtPredicateHelper import NbtPredicateHelper
from .TameableEntityHelper import TameableEntityHelper
from .BlockPosHelper import BlockPosHelper
from .TeamHelper import TeamHelper
from .FallingBlockEntityHelper import FallingBlockEntityHelper
from .ArmorStandEntityHelper import ArmorStandEntityHelper
from .AllayEntityHelper import AllayEntityHelper
from .InteractionEntityHelper import InteractionEntityHelper
from .LockButtonWidgetHelper_LockButtonBuilder import LockButtonWidgetHelper_LockButtonBuilder
from .StyleHelper import StyleHelper
from .StatusEffectHelper import StatusEffectHelper
from .StateHelper import StateHelper
from .ShulkerEntityHelper import ShulkerEntityHelper
from .PandaEntityHelper import PandaEntityHelper
from .OptionsHelper import OptionsHelper
from .HitResultHelper_Block import HitResultHelper_Block
from .TradeOfferHelper import TradeOfferHelper
from .ItemHelper import ItemHelper
from .CreativeItemStackHelper import CreativeItemStackHelper
from .UniversalBlockStateHelper import UniversalBlockStateHelper
from .NBTElementHelper import NBTElementHelper
from .PiglinEntityHelper import PiglinEntityHelper
from .GoatEntityHelper import GoatEntityHelper
from .PillagerEntityHelper import PillagerEntityHelper
from .InteractionManagerHelper import InteractionManagerHelper
from .ClickableWidgetHelper import ClickableWidgetHelper
from .FishEntityHelper import FishEntityHelper
from .IllagerEntityHelper import IllagerEntityHelper
from .EndermanEntityHelper import EndermanEntityHelper
from .PigEntityHelper import PigEntityHelper
from .DyeColorHelper import DyeColorHelper
from .HorseEntityHelper import HorseEntityHelper
from .TntMinecartEntityHelper import TntMinecartEntityHelper
from .ChunkHelper import ChunkHelper
from .BlockDataHelper import BlockDataHelper
from .ServerInfoHelper import ServerInfoHelper
from .SuggestionsBuilderHelper import SuggestionsBuilderHelper
from .TextHelper import TextHelper
from .PufferfishEntityHelper import PufferfishEntityHelper
from .PolarBearEntityHelper import PolarBearEntityHelper
from .RegistryHelper import RegistryHelper
from .AbstractPiglinEntityHelper import AbstractPiglinEntityHelper
from .OptionsHelper_ChatOptionsHelper import OptionsHelper_ChatOptionsHelper
from .SliderWidgetHelper_SliderBuilder import SliderWidgetHelper_SliderBuilder
from .IronGolemEntityHelper import IronGolemEntityHelper
from .DonkeyEntityHelper import DonkeyEntityHelper
from .AdvancementProgressHelper import AdvancementProgressHelper
from .BlazeEntityHelper import BlazeEntityHelper
from .LivingEntityHelper import LivingEntityHelper
from .BlockStateHelper import BlockStateHelper
from .OptionsHelper_SkinOptionsHelper import OptionsHelper_SkinOptionsHelper
from .TextDisplayEntityHelper_TextDisplayDataHelper import TextDisplayEntityHelper_TextDisplayDataHelper
from .NBTElementHelper_NBTNumberHelper import NBTElementHelper_NBTNumberHelper
from .ButtonWidgetHelper import ButtonWidgetHelper
from .MerchantEntityHelper import MerchantEntityHelper
from .SpiderEntityHelper import SpiderEntityHelper
from .BoatEntityHelper import BoatEntityHelper
from .PlayerListEntryHelper import PlayerListEntryHelper
from .CyclingButtonWidgetHelper import CyclingButtonWidgetHelper
from .StriderEntityHelper import StriderEntityHelper
from .AxolotlEntityHelper import AxolotlEntityHelper
from .AdvancementHelper import AdvancementHelper
from .TextFieldWidgetHelper_TextFieldBuilder import TextFieldWidgetHelper_TextFieldBuilder
from .BatEntityHelper import BatEntityHelper
from .OptionsHelper_AccessibilityOptionsHelper import OptionsHelper_AccessibilityOptionsHelper
from .RabbitEntityHelper import RabbitEntityHelper
from .BlockHelper import BlockHelper
from .SheepEntityHelper import SheepEntityHelper
from .AbstractHorseEntityHelper import AbstractHorseEntityHelper
from .VindicatorEntityHelper import VindicatorEntityHelper

File = TypeVar("java.io.File")




from typing import overload
from .PerExecLibrary import PerExecLibrary
from .BaseScriptContext import BaseScriptContext


class FTime(PerExecLibrary):
	"""Functions for getting and using raw java classes, methods and functions. 
An instance of this class is passed to scripts as the 'Time' variable.
	"""

	@overload
	def __init__(self, context: BaseScriptContext) -> None:
		pass

	@overload
	def time(self) -> float:
		"""

		Returns:
			current time in MS. 
		"""
		pass

	@overload
	def sleep(self, millis: float) -> None:
		"""Sleeps the current thread for the specified time in MS.

		Args:
			millis: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_client_recipebook_ClientRecipeBook = TypeVar("net_minecraft_client_recipebook_ClientRecipeBook")
ClientRecipeBook = net_minecraft_client_recipebook_ClientRecipeBook

net_minecraft_client_gui_screen_recipebook_RecipeBookResults = TypeVar("net_minecraft_client_gui_screen_recipebook_RecipeBookResults")
RecipeBookResults = net_minecraft_client_gui_screen_recipebook_RecipeBookResults


class IRecipeBookWidget:

	@overload
	def jsmacros_getResults(self) -> RecipeBookResults:
		pass

	@overload
	def jsmacros_isSearching(self) -> bool:
		pass

	@overload
	def jsmacros_refreshResultList(self) -> None:
		pass

	@overload
	def jsmacros_getRecipeBook(self) -> ClientRecipeBook:
		pass

	pass





from typing import overload
from .AbstractWidgetBuilder import AbstractWidgetBuilder
from .IScreen import IScreen
from .MethodWrapper import MethodWrapper
from .SliderWidgetHelper import SliderWidgetHelper


class SliderWidgetHelper_SliderBuilder(AbstractWidgetBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, screen: IScreen) -> None:
		pass

	@overload
	def getSteps(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the amount of steps of this slider. 
		"""
		pass

	@overload
	def steps(self, steps: int) -> "SliderWidgetHelper_SliderBuilder":
		"""
		Since: 1.8.4 

		Args:
			steps: the amount of steps for the slider. Must be greater or equal to 2 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getValue(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the initial value of the slider. 
		"""
		pass

	@overload
	def initially(self, value: int) -> "SliderWidgetHelper_SliderBuilder":
		"""
		Since: 1.8.4 

		Args:
			value: the initial value of the slider. Must be between 0 and steps - 1 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAction(self) -> MethodWrapper:
		"""
		Since: 1.8.4 

		Returns:
			the change listener of the slider. 
		"""
		pass

	@overload
	def action(self, action: MethodWrapper) -> "SliderWidgetHelper_SliderBuilder":
		"""

		Args:
			action: the change listener for the slider 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def createWidget(self) -> SliderWidgetHelper:
		pass

	pass





from typing import overload
from .IItemCooldownEntry import IItemCooldownEntry


class MixinItemCooldownEntry(IItemCooldownEntry):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getStartTick(self) -> int:
		pass

	@overload
	def jsmacros_getEndTick(self) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Set
from typing import Generic
from .LibraryRegistry import LibraryRegistry
from .BaseEventRegistry import BaseEventRegistry
from .ExtensionLoader import ExtensionLoader
from .ConfigManager import ConfigManager
from .ServiceManager import ServiceManager
from .JsMacrosThreadPool import JsMacrosThreadPool
from .EventContainer import EventContainer
from .BaseScriptContext import BaseScriptContext
from .ScriptTrigger import ScriptTrigger
from .BaseEvent import BaseEvent
from .BaseWrappedException import BaseWrappedException

java_util_function_Function_xyz_wagyourtail_jsmacros_core_Core_V,R_,R_ = TypeVar("java_util_function_Function_xyz_wagyourtail_jsmacros_core_Core_V,R_,R_")
Function = java_util_function_Function_xyz_wagyourtail_jsmacros_core_Core_V,R_,R_

T = TypeVar("T")
java_util_function_Consumer_java_lang_Throwable_ = TypeVar("java_util_function_Consumer_java_lang_Throwable_")
Consumer = java_util_function_Consumer_java_lang_Throwable_

U = TypeVar("U")
java_util_function_BiFunction_xyz_wagyourtail_jsmacros_core_Core_V,R_,org_slf4j_Logger,V_ = TypeVar("java_util_function_BiFunction_xyz_wagyourtail_jsmacros_core_Core_V,R_,org_slf4j_Logger,V_")
BiFunction = java_util_function_BiFunction_xyz_wagyourtail_jsmacros_core_Core_V,R_,org_slf4j_Logger,V_

java_lang_Runnable = TypeVar("java_lang_Runnable")
Runnable = java_lang_Runnable

java_lang_Throwable = TypeVar("java_lang_Throwable")
Throwable = java_lang_Throwable

org_slf4j_Logger = TypeVar("org_slf4j_Logger")
Logger = org_slf4j_Logger

java_io_File = TypeVar("java_io_File")
File = java_io_File


class Core(Generic[T, U]):
	libraryRegistry: LibraryRegistry
	eventRegistry: BaseEventRegistry
	extensions: ExtensionLoader
	profile: T
	config: ConfigManager
	services: ServiceManager
	threadPool: JsMacrosThreadPool

	@overload
	def getInstance(self) -> "Core":
		"""static reference to instance created by Core#<V,R>createInstance(java.util.function.Function<xyz.wagyourtail.jsmacros.core.Core<V,R>,R>,java.util.function.BiFunction<xyz.wagyourtail.jsmacros.core.Core<V,R>,org.slf4j.Logger,V>,java.io.File,java.io.File,org.slf4j.Logger)
		"""
		pass

	@overload
	def deferredInit(self) -> None:
		pass

	@overload
	def addContext(self, container: EventContainer) -> None:
		"""

		Args:
			container: 
		"""
		pass

	@overload
	def getContexts(self) -> Set[BaseScriptContext]:
		"""
		"""
		pass

	@overload
	def createInstance(self, eventRegistryFunction: Function, profileFunction: BiFunction, configFolder: File, macroFolder: File, logger: Logger) -> "Core":
		"""start by running this function, supplying implementations of BaseEventRegistry and BaseProfile and a Supplier for
creating the config manager with the folder paths it needs.

		Args:
			eventRegistryFunction: 
			logger: 
			macroFolder: 
			profileFunction: 
			configFolder: 
		"""
		pass

	@overload
	def exec(self, macro: ScriptTrigger, event: BaseEvent) -> EventContainer:
		"""executes an BaseEvent on a $ ScriptTrigger

		Args:
			macro: 
			event: 
		"""
		pass

	@overload
	def exec(self, macro: ScriptTrigger, event: BaseEvent, then: Runnable, catcher: Consumer) -> EventContainer:
		"""Executes an BaseEvent on a $ ScriptTrigger with callback.

		Args:
			macro: 
			catcher: 
			then: 
			event: 
		"""
		pass

	@overload
	def exec(self, lang: str, script: str, fakeFile: File, event: BaseEvent, then: Runnable, catcher: Consumer) -> EventContainer:
		"""
		Since: 1.7.0 

		Args:
			catcher: 
			fakeFile: 
			then: 
			lang: 
			event: 
			script: 
		"""
		pass

	@overload
	def wrapException(self, ex: Throwable) -> BaseWrappedException:
		"""wraps an exception for more uniform parsing between languages, also extracts useful info.

		Args:
			ex: exception to wrap. 
		"""
		pass

	pass





from typing import overload


class MixinInteractionEntity2:

	@overload
	def callGetInteractionWidth(self) -> float:
		pass

	@overload
	def callGetInteractionHeight(self) -> float:
		pass

	@overload
	def callShouldRespond(self) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MerchantEntityHelper import MerchantEntityHelper

net_minecraft_entity_passive_VillagerEntity = TypeVar("net_minecraft_entity_passive_VillagerEntity")
VillagerEntity = net_minecraft_entity_passive_VillagerEntity


class VillagerEntityHelper(MerchantEntityHelper):
	"""
	Since: 1.6.3 
	"""

	@overload
	def __init__(self, e: VillagerEntity) -> None:
		pass

	@overload
	def getProfession(self) -> str:
		"""
		Since: 1.6.3 
		"""
		pass

	@overload
	def getStyle(self) -> str:
		"""
		Since: 1.6.3 
		"""
		pass

	@overload
	def getLevel(self) -> int:
		"""
		Since: 1.6.3 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_LivingEntity = TypeVar("net_minecraft_entity_LivingEntity")
LivingEntity = net_minecraft_entity_LivingEntity

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class MixinPlayerEntity(LivingEntity):

	@overload
	def setCustomName(self, name: Text) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .SelectCursor import SelectCursor

java_util_function_Consumer_java_lang_String_ = TypeVar("java_util_function_Consumer_java_lang_String_")
Consumer = java_util_function_Consumer_java_lang_String_


class History:
	"""
	"""
	onChange: Consumer
	current: str

	@overload
	def __init__(self, start: str, cursor: SelectCursor) -> None:
		pass

	@overload
	def addChar(self, position: int, content: str) -> bool:
		"""

		Args:
			position: 
			content: 

		Returns:
			is new step. 
		"""
		pass

	@overload
	def add(self, position: int, content: str) -> bool:
		pass

	@overload
	def deletePos(self, position: int, length: int) -> bool:
		"""

		Args:
			position: 

		Returns:
			is new step. 
		"""
		pass

	@overload
	def bkspacePos(self, position: int, length: int) -> bool:
		"""

		Args:
			position: 

		Returns:
			is new step 
		"""
		pass

	@overload
	def shiftLine(self, startLine: int, lines: int, shiftDown: bool) -> bool:
		pass

	@overload
	def replace(self, position: int, length: int, content: str) -> None:
		pass

	@overload
	def tabLines(self, startLine: int, lineCount: int, reverse: bool) -> None:
		pass

	@overload
	def tabLinesKeepCursor(self, startLine: int, startLineIndex: int, endLineIndex: int, lineCount: int, reverse: bool) -> None:
		pass

	@overload
	def undo(self) -> int:
		"""

		Returns:
			position of step. -1 if nothing to undo. 
		"""
		pass

	@overload
	def redo(self) -> int:
		"""

		Returns:
			position of step. -1 if nothing to redo. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseLibrary import BaseLibrary
from .TextHelper import TextHelper

T = TypeVar("T")

class FUtils(BaseLibrary):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def openUrl(self, url: str) -> None:
		"""
		Since: 1.8.4 

		Args:
			url: the url to open 
		"""
		pass

	@overload
	def openFile(self, path: str) -> None:
		"""
		Since: 1.8.4 

		Args:
			path: the path top open, relative the config folder 
		"""
		pass

	@overload
	def copyToClipboard(self, text: str) -> None:
		"""Copies the text to the clipboard.\n
		Since: 1.8.4 

		Args:
			text: the text to copy 
		"""
		pass

	@overload
	def getClipboard(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the text from the clipboard. 
		"""
		pass

	@overload
	def guessName(self, text: TextHelper) -> str:
		"""Tries to guess the name of the sender of a given message. This is not guaranteed to work and
for specific servers it may be better to use regex instead.\n
		Since: 1.8.4 

		Args:
			text: the text to check 

		Returns:
			the name of the sender or 'null' if it couldn't be guessed. 
		"""
		pass

	@overload
	def guessName(self, text: str) -> str:
		"""Tries to guess the name of the sender of a given message. This is not guaranteed to work and
for specific servers it may be better to use regex instead.\n
		Since: 1.8.4 

		Args:
			text: the text to check 

		Returns:
			the name of the sender or 'null' if it couldn't be guessed. 
		"""
		pass

	@overload
	def guessNameAndRoles(self, text: TextHelper) -> List[str]:
		"""Tries to guess the name, as well as the titles and roles of the sender of the given message.
This is not guaranteed to work and for specific servers it may be better to use regex
instead.\n
		Since: 1.8.4 

		Args:
			text: the text to check 

		Returns:
			a list of names, titles and roles of the sender or an empty list if it couldn't be
guessed. 
		"""
		pass

	@overload
	def guessNameAndRoles(self, text: str) -> List[str]:
		"""Tries to guess the name, as well as the titles and roles of the sender of the given message.
This is not guaranteed to work and for specific servers it may be better to use regex
instead.\n
		Since: 1.8.4 

		Args:
			text: the text to check 

		Returns:
			a list of names, titles and roles of the sender or an empty list if it couldn't be
guessed. 
		"""
		pass

	@overload
	def hashString(self, message: str) -> str:
		"""Hashes the given string with sha-256.\n
		Since: 1.8.4 

		Args:
			message: the message to hash 

		Returns:
			the hashed message. 
		"""
		pass

	@overload
	def hashString(self, message: str, algorithm: str) -> str:
		"""Hashes the given string with the selected algorithm.\n
		Since: 1.8.4 

		Args:
			message: the message to hash 
			algorithm: sha1 | sha256 | sha384 | sha512 | md2 | md5 

		Returns:
			the hashed message (Hex) 
		"""
		pass

	@overload
	def hashString(self, message: str, algorithm: str, base64: bool) -> str:
		"""Hashes the given string with the selected algorithm.\n
		Since: 1.9.1 

		Args:
			base64: encode the result in base64 
			message: the message to hash 
			algorithm: sha1 | sha256 | sha384 | sha512 | md2 | md5 

		Returns:
			the hashed message (Hex or Base64) 
		"""
		pass

	@overload
	def encode(self, message: str) -> str:
		"""Encodes the given string with Base64.\n
		Since: 1.8.4 

		Args:
			message: the message to encode 

		Returns:
			the encoded message. 
		"""
		pass

	@overload
	def decode(self, message: str) -> str:
		"""Decodes the given string with Base64.\n
		Since: 1.8.4 

		Args:
			message: the message to decode 

		Returns:
			the decoded message. 
		"""
		pass

	@overload
	def requireNonNull(self, obj: T) -> T:
		"""Checks that the specified object reference is not 'null' .\n
		Since: 1.9.1 

		Args:
			obj: the object reference to check for nullity 

		Returns:
			'obj' if not 'null' 
		"""
		pass

	@overload
	def requireNonNull(self, obj: T, message: str) -> T:
		"""Checks that the specified object reference is not 'null' and
throws a customized NullPointerException if it is.\n
		Since: 1.9.1 

		Args:
			obj: the object reference to check for nullity 
			message: detail message to be used in the event that a '
               NullPointerException' is thrown 

		Returns:
			'obj' if not 'null' 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

T = TypeVar("T")
U = TypeVar("U")

class Pair(Generic[T, U]):

	@overload
	def __init__(self, t: T, u: U) -> None:
		pass

	@overload
	def setU(self, u: U) -> None:
		pass

	@overload
	def setT(self, t: T) -> None:
		pass

	@overload
	def getU(self) -> U:
		pass

	@overload
	def getT(self) -> T:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .Inventory import Inventory
from .ItemStackHelper import ItemStackHelper

net_minecraft_client_gui_screen_ingame_BrewingStandScreen = TypeVar("net_minecraft_client_gui_screen_ingame_BrewingStandScreen")
BrewingStandScreen = net_minecraft_client_gui_screen_ingame_BrewingStandScreen


class BrewingStandInventory(Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, inventory: BrewingStandScreen) -> None:
		pass

	@overload
	def isBrewablePotion(self, potion: ItemStackHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			potion: the potion to check 

		Returns:
			'true' if the given potion is can be brewed, 'false' otherwise. 
		"""
		pass

	@overload
	def isValidIngredient(self, ingredient: ItemStackHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			ingredient: the item to check 

		Returns:
			'true' if the given item is a valid ingredient, 'false' otherwise. 
		"""
		pass

	@overload
	def isValidRecipe(self, potion: ItemStackHelper, ingredient: ItemStackHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			potion: the potion to check 
			ingredient: the ingredient to check 

		Returns:
			'true' if the given potion and ingredient can be brewed together, 'false' otherwise. 
		"""
		pass

	@overload
	def getFuelCount(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the left fuel. 
		"""
		pass

	@overload
	def getMaxFuelUses(self) -> int:
		"""The maximum fuel count is a constant with the value 20.\n
		Since: 1.8.4 

		Returns:
			the maximum fuel. 
		"""
		pass

	@overload
	def canBrewCurrentInput(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the brewing stand can brew any of the held potions with the current
ingredient, 'false' otherwise. 
		"""
		pass

	@overload
	def getBrewTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the time the potions have been brewing. 
		"""
		pass

	@overload
	def getRemainingTicks(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the remaining time the potions have to brew. 
		"""
		pass

	@overload
	def previewPotion(self, potion: ItemStackHelper, ingredient: ItemStackHelper) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Args:
			potion: the potion 
			ingredient: the ingredient 

		Returns:
			the resulting potion of the given potion and ingredient if it exists and the potion
itself otherwise. 
		"""
		pass

	@overload
	def previewPotions(self) -> List[ItemStackHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all resulting potions of the current input. 
		"""
		pass

	@overload
	def getIngredient(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the ingredient. 
		"""
		pass

	@overload
	def getFuel(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the fuel item. 
		"""
		pass

	@overload
	def getFirstPotion(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the first potion. 
		"""
		pass

	@overload
	def getSecondPotion(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the second potion. 
		"""
		pass

	@overload
	def getThirdPotion(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the third potion. 
		"""
		pass

	@overload
	def getPotions(self) -> List[ItemStackHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of the potions inside the brewing stand. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .Inventory import Inventory
from .ItemStackHelper import ItemStackHelper

net_minecraft_client_gui_screen_ingame_StonecutterScreen = TypeVar("net_minecraft_client_gui_screen_ingame_StonecutterScreen")
StonecutterScreen = net_minecraft_client_gui_screen_ingame_StonecutterScreen


class StoneCutterInventory(Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, inventory: StonecutterScreen) -> None:
		pass

	@overload
	def getSelectedRecipeIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the selected recipe index. 
		"""
		pass

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the output item for the selected recipe. 
		"""
		pass

	@overload
	def selectRecipe(self, idx: int) -> "StoneCutterInventory":
		"""
		Since: 1.8.4 

		Args:
			idx: the index to select 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAvailableRecipeCount(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the amount of available recipes. 
		"""
		pass

	@overload
	def getRecipes(self) -> List[ItemStackHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all available recipe results in the form of item stacks. 
		"""
		pass

	@overload
	def canCraft(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if there is a selected recipe, 'false' otherwise. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .IPackedIntegerArray import IPackedIntegerArray


class MixinPackedIntegerArray(IPackedIntegerArray):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getMaxValue(self) -> float:
		pass

	@overload
	def jsmacros_getElementsPerLong(self) -> int:
		pass

	@overload
	def jsmacros_getIndexScale(self) -> int:
		pass

	@overload
	def jsmacros_getIndexOffset(self) -> int:
		pass

	@overload
	def jsmacros_getIndexShift(self) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from .Inventory import Inventory
from .ItemStackHelper import ItemStackHelper

net_minecraft_client_gui_screen_ingame_GrindstoneScreen = TypeVar("net_minecraft_client_gui_screen_ingame_GrindstoneScreen")
GrindstoneScreen = net_minecraft_client_gui_screen_ingame_GrindstoneScreen


class GrindStoneInventory(Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, inventory: GrindstoneScreen) -> None:
		pass

	@overload
	def getTopInput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the upper item to disenchant. 
		"""
		pass

	@overload
	def getBottomInput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the bottom item to disenchant. 
		"""
		pass

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the expected output item. 
		"""
		pass

	@overload
	def simulateXp(self) -> int:
		"""Returns the minimum amount of xp dropped when disenchanting the input items. To calculate the
maximum amount of xp, just multiply the return value by 2.\n
		Since: 1.8.4 

		Returns:
			the minimum amount of xp the grindstone should return. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

com_mojang_brigadier_tree_CommandNode = TypeVar("com_mojang_brigadier_tree_CommandNode")
CommandNode = com_mojang_brigadier_tree_CommandNode


class CommandNodeHelper(BaseHelper):
	fabric: CommandNode

	@overload
	def __init__(self, base: CommandNode, fabric: CommandNode) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .Vec2D import Vec2D
from .Pos3D import Pos3D

org_joml_Vector3f = TypeVar("org_joml_Vector3f")
Vector3f = org_joml_Vector3f


class Vec3D(Vec2D):
	"""
	Since: 1.2.6 [citation needed] 
	"""
	z1: float
	z2: float

	@overload
	def __init__(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> None:
		pass

	@overload
	def __init__(self, start: Pos3D, end: Pos3D) -> None:
		pass

	@overload
	def getZ1(self) -> float:
		pass

	@overload
	def getZ2(self) -> float:
		pass

	@overload
	def getDeltaZ(self) -> float:
		pass

	@overload
	def getStart(self) -> Pos3D:
		pass

	@overload
	def getEnd(self) -> Pos3D:
		pass

	@overload
	def getMagnitude(self) -> float:
		pass

	@overload
	def getMagnitudeSq(self) -> float:
		pass

	@overload
	def add(self, vec: "Vec3D") -> "Vec3D":
		pass

	@overload
	def addStart(self, pos: Pos3D) -> "Vec3D":
		"""
		Since: 1.6.4 

		Args:
			pos: 
		"""
		pass

	@overload
	def addEnd(self, pos: Pos3D) -> "Vec3D":
		"""
		Since: 1.6.4 

		Args:
			pos: 
		"""
		pass

	@overload
	def addStart(self, x: float, y: float, z: float) -> "Vec3D":
		"""
		Since: 1.6.4 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def addEnd(self, x: float, y: float, z: float) -> "Vec3D":
		"""
		Since: 1.6.4 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def add(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> "Vec3D":
		"""
		Since: 1.6.3 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def multiply(self, vec: "Vec3D") -> "Vec3D":
		pass

	@overload
	def multiply(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> "Vec3D":
		"""
		Since: 1.6.3 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def scale(self, scale: float) -> "Vec3D":
		"""
		Since: 1.6.3 

		Args:
			scale: 
		"""
		pass

	@overload
	def normalize(self) -> "Vec3D":
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getPitch(self) -> float:
		pass

	@overload
	def getYaw(self) -> float:
		pass

	@overload
	def dotProduct(self, vec: "Vec3D") -> float:
		pass

	@overload
	def crossProduct(self, vec: "Vec3D") -> "Vec3D":
		pass

	@overload
	def reverse(self) -> "Vec3D":
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def toMojangFloatVector(self) -> Vector3f:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def compareTo(self, o: "Vec3D") -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IResourcePackManager import IResourcePackManager

net_minecraft_resource_ResourcePackProfile = TypeVar("net_minecraft_resource_ResourcePackProfile")
ResourcePackProfile = net_minecraft_resource_ResourcePackProfile


class MixinResourcePackManager(IResourcePackManager):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_disableServerPacks(self, disable: bool) -> None:
		pass

	@overload
	def jsmacros_isServerPacksDisabled(self) -> bool:
		pass

	@overload
	def onBuildPackList(self, instance: ResourcePackProfile) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .BlockPosHelper import BlockPosHelper
from .EntityHelper import EntityHelper
from .HitResultHelper import HitResultHelper
from .InteractionProxy_Break_BreakBlockResult import InteractionProxy_Break_BreakBlockResult
from .MethodWrapper import MethodWrapper

net_minecraft_client_network_ClientPlayerInteractionManager = TypeVar("net_minecraft_client_network_ClientPlayerInteractionManager")
ClientPlayerInteractionManager = net_minecraft_client_network_ClientPlayerInteractionManager


class InteractionManagerHelper(BaseHelper):
	"""Helper for ClientPlayerInteractionManager
it accesses interaction manager from 'mc' instead of 'base' , to avoid issues\n
	Since: 1.9.0 
	"""
	autoUpdateBase: bool

	@overload
	def __init__(self, base: ClientPlayerInteractionManager) -> None:
		pass

	@overload
	def checkBase(self, update: bool) -> bool:
		"""checks if the base matches the current manager

		Args:
			update: true if the base should be updated. otherwise it'll raise an error if it's not up-to-date 

		Returns:
			true if base is available 
		"""
		pass

	@overload
	def getGameMode(self) -> str:
		"""
		Since: 1.9.0 

		Returns:
			the player's current gamemode. 
		"""
		pass

	@overload
	def setGameMode(self, gameMode: str) -> "InteractionManagerHelper":
		"""
		Since: 1.9.0 

		Args:
			gameMode: possible values are survival, creative, adventure, spectator (case insensitive) 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTarget(self, x: int, y: int, z: int) -> "InteractionManagerHelper":
		"""sets crosshair target to a block\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTarget(self, x: int, y: int, z: int, direction: str) -> "InteractionManagerHelper":
		"""sets crosshair target to a block\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTarget(self, x: int, y: int, z: int, direction: int) -> "InteractionManagerHelper":
		"""sets crosshair target to a block\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTarget(self, pos: BlockPosHelper) -> "InteractionManagerHelper":
		"""sets crosshair target to a block\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTarget(self, pos: BlockPosHelper, direction: str) -> "InteractionManagerHelper":
		"""sets crosshair target to a block\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTarget(self, pos: BlockPosHelper, direction: int) -> "InteractionManagerHelper":
		"""sets crosshair target to a block\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTarget(self, entity: EntityHelper) -> "InteractionManagerHelper":
		"""sets crosshair target to an entity\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def getTarget(self) -> HitResultHelper:
		"""
		Since: 1.9.1 

		Returns:
			current hitResult 
		"""
		pass

	@overload
	def getTargetedBlock(self) -> BlockPosHelper:
		"""
		Since: 1.9.0 

		Returns:
			targeted block pos, null if not targeting block 
		"""
		pass

	@overload
	def getTargetedEntity(self) -> EntityHelper:
		"""
		Since: 1.9.0 

		Returns:
			targeted entity, null if not targeting entity 
		"""
		pass

	@overload
	def setTargetMissed(self) -> "InteractionManagerHelper":
		"""sets crosshair target to missed (doesn't target anything)\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def hasTargetOverride(self) -> bool:
		"""
		Since: 1.9.0 

		Returns:
			'true' if target have been set by 'ClientPlayerEntityHelper#setTarget()' or 'ClientPlayerEntityHelper#setTargetMissed()' 
		"""
		pass

	@overload
	def clearTargetOverride(self) -> "InteractionManagerHelper":
		"""clears target override\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTargetRangeCheck(self, enabled: bool, autoClear: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.9.0 

		Args:
			autoClear: if override should clear when out of range.
                 if 'false' , target will set to missed if out of range. default is 'true' 
			enabled: if target overriding should check range. default is 'true' 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTargetAirCheck(self, enabled: bool, autoClear: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.9.0 

		Args:
			autoClear: if override should clear when is air.
                 if 'false' , target will set to missed if is air. default is 'false' 
			enabled: if target overriding should check air. default is 'false' 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setTargetShapeCheck(self, enabled: bool, autoClear: bool) -> "InteractionManagerHelper":
		"""this check ignores air. use 'ClientPlayerEntityHelper#setTargetAirCheck()' to check air.\n
		Since: 1.9.0 

		Args:
			autoClear: if override should clear when shape is empty.
                 if 'false' , target will set to missed if is empty. default is 'false' 
			enabled: if target overriding should check block shape. default is 'true' 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def resetTargetChecks(self) -> "InteractionManagerHelper":
		"""resets all range, air and shape check settings to default.\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def attack(self) -> "InteractionManagerHelper":
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def attack(self, await_: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
		"""
		pass

	@overload
	def attack(self, entity: EntityHelper) -> "InteractionManagerHelper":
		"""
		Since: 1.5.0 

		Args:
			entity: 
		"""
		pass

	@overload
	def attack(self, entity: EntityHelper, await_: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
			entity: 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: str) -> "InteractionManagerHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to attack 
			y: the y coordinate to attack 
			z: the z coordinate to attack 
			direction: possible values are "up", "down", "north", "south", "east", "west" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: int) -> "InteractionManagerHelper":
		"""
		Since: 1.5.0 

		Args:
			x: 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: str, await_: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to attack 
			await: whether to wait for the attack to finish 
			y: the y coordinate to attack 
			z: the z coordinate to attack 
			direction: possible values are "up", "down", "north", "south", "east", "west" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: int, await_: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.6.0 

		Args:
			x: 
			await: 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
		"""
		pass

	@overload
	def breakBlock(self) -> InteractionProxy_Break_BreakBlockResult:
		"""breaks a block, will wait till it's done you can use 'ClientPlayerEntityHelper#setTarget()' to specify which block to break\n
		Since: 1.9.0 

		Returns:
			result, or null if interaction manager is unavailable 
		"""
		pass

	@overload
	def breakBlock(self, x: int, y: int, z: int) -> InteractionProxy_Break_BreakBlockResult:
		"""breaks a block, will wait till it's done this is the same as: setTarget(x, y, z);
let res = null;
if (getTargetedBlock()?.getRaw().equals(new BlockPos(x, y, z))) res = breakBlock();
clearTargetOverride();
return res;\n
		Since: 1.9.0 

		Returns:
			result 
		"""
		pass

	@overload
	def breakBlock(self, pos: BlockPosHelper) -> InteractionProxy_Break_BreakBlockResult:
		"""breaks a block, will wait till it's done this is the same as: setTarget(pos);
let res = null;
if (getTargetedBlock()?.equals(pos)) res = breakBlock();
clearTargetOverride();
return res;\n
		Since: 1.9.0 

		Returns:
			result 
		"""
		pass

	@overload
	def breakBlockAsync(self, callback: MethodWrapper) -> "InteractionManagerHelper":
		"""starts breaking a block you can use 'ClientPlayerEntityHelper#setTarget()' to specify which block to break\n
		Since: 1.9.0 

		Args:
			callback: this will mostly be called on main thread!
                Use 'methodToJavaAsync()' instead of 'methodToJava()' to avoid errors. 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def isBreakingBlock(self) -> bool:
		"""
		Since: 1.8.0 
		"""
		pass

	@overload
	def hasBreakBlockOverride(self) -> bool:
		"""
		Since: 1.9.0 

		Returns:
			'true' if there's not finished block breaking from 'ClientPlayerEntityHelper#breakBlock()' 
		"""
		pass

	@overload
	def cancelBreakBlock(self) -> "InteractionManagerHelper":
		"""cancels breaking block that previously started by 'ClientPlayerEntityHelper#breakBlock()' or 'ClientPlayerEntityHelper#breakBlockAsync()'\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def interact(self) -> "InteractionManagerHelper":
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def interact(self, await_: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
		"""
		pass

	@overload
	def interactEntity(self, entity: EntityHelper, offHand: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			entity: 
			offHand: 
		"""
		pass

	@overload
	def interactEntity(self, entity: EntityHelper, offHand: bool, await_: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
			entity: 
			offHand: 
		"""
		pass

	@overload
	def interactItem(self, offHand: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			offHand: 
		"""
		pass

	@overload
	def interactItem(self, offHand: bool, await_: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
			offHand: 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: str, offHand: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to interact 
			y: the y coordinate to interact 
			z: the z coordinate to interact 
			direction: possible values are "up", "down", "north", "south", "east", "west" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: int, offHand: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			x: 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
			offHand: 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: str, offHand: bool, await_: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to interact 
			await: whether to wait for the interaction to complete 
			y: the y coordinate to interact 
			z: the z coordinate to interact 
			direction: possible values are "up", "down", "north", "south", "east", "west" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: int, offHand: bool, await_: bool) -> "InteractionManagerHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			x: 
			await: whether to wait for the interaction to complete 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
			offHand: 
		"""
		pass

	@overload
	def holdInteract(self, holding: bool) -> "InteractionManagerHelper":
		"""starts/stops long interact\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def holdInteract(self, holding: bool, awaitFirstClick: bool) -> "InteractionManagerHelper":
		"""starts/stops long interact\n
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def holdInteract(self, ticks: int) -> int:
		"""interacts for specified number of ticks\n
		Since: 1.9.0 

		Returns:
			remaining ticks if the interaction was interrupted 
		"""
		pass

	@overload
	def holdInteract(self, ticks: int, stopOnPause: bool) -> int:
		"""interacts for specified number of ticks\n
		Since: 1.9.0 

		Args:
			stopOnPause: if 'false' , this interaction will not return when interrupted by pause.
                   the timer will not decrease, meaning it'll continue right after unpause and interact exact amount of ticks. 

		Returns:
			remaining ticks if the interaction was interrupted 
		"""
		pass

	@overload
	def hasInteractOverride(self) -> bool:
		"""
		Since: 1.9.0 

		Returns:
			'true' if interaction from 'ClientPlayerEntityHelper#holdInteract()' is active 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

io_noties_prism4j_Prism4j_Grammar = TypeVar("io_noties_prism4j_Prism4j_Grammar")
Prism4j_Grammar = io_noties_prism4j_Prism4j_Grammar

io_noties_prism4j_Prism4j = TypeVar("io_noties_prism4j_Prism4j")
Prism4j = io_noties_prism4j_Prism4j


class Prism_regex:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def create(self, prism4j: Prism4j) -> Prism4j_Grammar:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper

net_minecraft_entity_passive_AllayEntity = TypeVar("net_minecraft_entity_passive_AllayEntity")
AllayEntity = net_minecraft_entity_passive_AllayEntity


class AllayEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: AllayEntity) -> None:
		pass

	@overload
	def isDancing(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this allay is dancing, 'false' otherwise. 
		"""
		pass

	@overload
	def canDuplicate(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this allay can be duplicated, 'false' otherwise. 
		"""
		pass

	@overload
	def isHoldingItem(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this allay is holding a item, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

T = TypeVar("T")
net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_render_BufferBuilder = TypeVar("net_minecraft_client_render_BufferBuilder")
BufferBuilder = net_minecraft_client_render_BufferBuilder


class RenderElement3D(Comparable, Generic[T]):

	@overload
	def render(self, drawContext: DrawContext, builder: BufferBuilder, tickDelta: float) -> None:
		pass

	@overload
	def compareTo(self, o: "RenderElement3D") -> int:
		pass

	@overload
	def compareToSame(self, other: T) -> int:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .ItemStackHelper import ItemStackHelper

net_minecraft_recipe_RecipeEntry__ = TypeVar("net_minecraft_recipe_RecipeEntry__")
RecipeEntry = net_minecraft_recipe_RecipeEntry__


class RecipeHelper(BaseHelper):
	"""
	Since: 1.3.1 
	"""

	@overload
	def __init__(self, base: RecipeEntry, syncId: int) -> None:
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def getIngredients(self) -> List[List[ItemStackHelper]]:
		"""get ingredients list\n
		Since: 1.8.3 
		"""
		pass

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def craft(self, craftAll: bool) -> "RecipeHelper":
		"""
		Since: 1.3.1 

		Args:
			craftAll: 
		"""
		pass

	@overload
	def getGroup(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the type of this recipe. 
		"""
		pass

	@overload
	def hasRecipeRemainders(self) -> bool:
		"""This will not account for the actual items used in the recipe, but only the default recipe
itself. Items with durability or with a lot of tags will probably not work correctly.\n
		Since: 1.8.4 

		Returns:
			will return 'true' if any of the default ingredients have a recipe remainder. 
		"""
		pass

	@overload
	def getRecipeRemainders(self) -> List[List[ItemStackHelper]]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all possible recipe remainders. 
		"""
		pass

	@overload
	def getType(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the type of this recipe. 
		"""
		pass

	@overload
	def canCraft(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the recipe can be crafted with the current inventory, 'false' otherwise. 
		"""
		pass

	@overload
	def canCraft(self, amount: int) -> bool:
		"""
		Since: 1.8.4 

		Args:
			amount: the amount of items to craft 

		Returns:
			'true' if the given amount of items can be crafted with the current inventory, 'false' otherwise. 
		"""
		pass

	@overload
	def getCraftableAmount(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			how often the recipe can be crafted with the current player inventory. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import Mapping
from typing import Set
from .Core import Core
from .ScriptTrigger import ScriptTrigger
from .IEventListener import IEventListener


class BaseEventRegistry:
	"""
	Since: 1.2.7 
	"""
	oldEvents: Mapping[str, str]
	events: Set[str]
	cancellableEvents: Set[str]
	joinableEvents: Set[str]
	filterableEvents: Mapping[str, Class]

	@overload
	def __init__(self, runner: Core) -> None:
		pass

	@overload
	def clearMacros(self) -> None:
		pass

	@overload
	def addScriptTrigger(self, rawmacro: ScriptTrigger) -> None:
		"""
		Since: 1.1.2 [citation needed] 

		Args:
			rawmacro: 
		"""
		pass

	@overload
	def addListener(self, event: str, listener: IEventListener) -> None:
		"""
		Since: 1.2.3 

		Args:
			listener: 
			event: 
		"""
		pass

	@overload
	def removeListener(self, event: str, listener: IEventListener) -> bool:
		"""
		Since: 1.2.3 

		Args:
			listener: 
			event: 
		"""
		pass

	@overload
	def removeListener(self, listener: IEventListener) -> bool:
		"""
		Since: 1.2.3 

		Args:
			listener: 
		"""
		pass

	@overload
	def removeScriptTrigger(self, rawmacro: ScriptTrigger) -> bool:
		"""
		Since: 1.1.2 [citation needed] 

		Args:
			rawmacro: 
		"""
		pass

	@overload
	def getListeners(self) -> Mapping[str, Set[IEventListener]]:
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def getListeners(self, key: str) -> Set[IEventListener]:
		"""
		Since: 1.2.3 

		Args:
			key: 
		"""
		pass

	@overload
	def getScriptTriggers(self) -> List[ScriptTrigger]:
		"""
		Since: 1.1.2 [citation needed] 
		"""
		pass

	@overload
	def addEvent(self, eventName: str) -> None:
		"""
		Since: 1.1.2 [citation needed] 

		Args:
			eventName: 
		"""
		pass

	@overload
	def addEvent(self, eventName: str, joinable: bool) -> None:
		pass

	@overload
	def addEvent(self, eventName: str, joinable: bool, cancellable: bool) -> None:
		pass

	@overload
	def addEvent(self, clazz: Class) -> None:
		pass

	pass





from typing import overload
from .Pos2D import Pos2D
from .Draw3D import Draw3D
from .Pos3D import Pos3D
from .BlockPosHelper import BlockPosHelper
from .TraceLine import TraceLine


class TraceLine_Builder:
	screenPos: Pos2D

	@overload
	def __init__(self, parent: Draw3D) -> None:
		pass

	@overload
	def pos(self, pos: Pos3D) -> "TraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			pos: the position of the target 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def pos(self, pos: BlockPosHelper) -> "TraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			pos: the position of the target 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def pos(self, x: int, y: int, z: int) -> "TraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			x: the x coordinate of the target 
			y: the y coordinate of the target 
			z: the z coordinate of the target 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def getPos(self) -> Pos3D:
		"""
		Since: 1.9.0 

		Returns:
			the position of the target 
		"""
		pass

	@overload
	def color(self, color: int) -> "TraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			color: the color of the line 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def color(self, color: int, alpha: int) -> "TraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			color: the color of the line 
			alpha: the alpha value of the line's color 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int) -> "TraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int, a: int) -> "TraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			a: the alpha value of the color 
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.9.0 

		Returns:
			the color of the line 
		"""
		pass

	@overload
	def alpha(self, alpha: int) -> "TraceLine_Builder":
		"""
		Since: 1.9.0 

		Args:
			alpha: the alpha value for the line's color 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def getAlpha(self) -> int:
		"""
		Since: 1.9.0 

		Returns:
			the alpha value of the line's color 
		"""
		pass

	@overload
	def buildAndAdd(self) -> TraceLine:
		"""Creates the trace line for the given values and adds it to the draw3D\n
		Since: 1.9.0 

		Returns:
			the build line 
		"""
		pass

	@overload
	def build(self) -> TraceLine:
		"""Builds the line from the given values\n
		Since: 1.9.0 

		Returns:
			the build line 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper
from .ItemStackHelper import ItemStackHelper

net_minecraft_entity_mob_WitchEntity = TypeVar("net_minecraft_entity_mob_WitchEntity")
WitchEntity = net_minecraft_entity_mob_WitchEntity


class WitchEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: WitchEntity) -> None:
		pass

	@overload
	def isDrinkingPotion(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this witch is drinking a potion, 'false' otherwise. 
		"""
		pass

	@overload
	def getPotion(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the held potion item. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .Inventory import Inventory
from .ItemStackHelper import ItemStackHelper

net_minecraft_client_gui_screen_ingame_AnvilScreen = TypeVar("net_minecraft_client_gui_screen_ingame_AnvilScreen")
AnvilScreen = net_minecraft_client_gui_screen_ingame_AnvilScreen


class AnvilInventory(Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, inventory: AnvilScreen) -> None:
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the currently set name to be applied. 
		"""
		pass

	@overload
	def setName(self, name: str) -> "AnvilInventory":
		"""The change will be applied once the item is taken out of the anvil.\n
		Since: 1.8.4 

		Args:
			name: the new item name 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getLevelCost(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the level cost to apply the changes. 
		"""
		pass

	@overload
	def getItemRepairCost(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the amount of item needed to fully repair the item. 
		"""
		pass

	@overload
	def getMaximumLevelCost(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum default level cost. 
		"""
		pass

	@overload
	def getLeftInput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the first input item. 
		"""
		pass

	@overload
	def getRightInput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the second input item. 
		"""
		pass

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the expected output item. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .StateHelper import StateHelper
from .BlockHelper import BlockHelper
from .FluidStateHelper import FluidStateHelper
from .BlockPosHelper import BlockPosHelper
from .UniversalBlockStateHelper import UniversalBlockStateHelper

net_minecraft_block_BlockState = TypeVar("net_minecraft_block_BlockState")
BlockState = net_minecraft_block_BlockState


class BlockStateHelper(StateHelper):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, base: BlockState) -> None:
		pass

	@overload
	def getBlock(self) -> BlockHelper:
		"""
		Since: 1.6.5 

		Returns:
			the block the state belongs to. 
		"""
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the block's id. 
		"""
		pass

	@overload
	def getFluidState(self) -> FluidStateHelper:
		"""
		Since: 1.8.4 

		Returns:
			the fluid state of this block state. 
		"""
		pass

	@overload
	def getHardness(self) -> float:
		"""
		Since: 1.6.5 

		Returns:
			the hardness. 
		"""
		pass

	@overload
	def getLuminance(self) -> int:
		"""
		Since: 1.6.5 

		Returns:
			the luminance. 
		"""
		pass

	@overload
	def emitsRedstonePower(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state emits redstone power. 
		"""
		pass

	@overload
	def exceedsCube(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the shape of the state is a cube. 
		"""
		pass

	@overload
	def isAir(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state is air. 
		"""
		pass

	@overload
	def isOpaque(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state is opaque. 
		"""
		pass

	@overload
	def isToolRequired(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if a tool is required to mine the block. 
		"""
		pass

	@overload
	def hasBlockEntity(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state has a block entity. 
		"""
		pass

	@overload
	def hasRandomTicks(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state can be random ticked. 
		"""
		pass

	@overload
	def hasComparatorOutput(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state has a comparator output. 
		"""
		pass

	@overload
	def getPistonBehaviour(self) -> str:
		"""
		Since: 1.6.5 

		Returns:
			the piston behaviour of the state. 
		"""
		pass

	@overload
	def blocksMovement(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state blocks the movement of entities. 
		"""
		pass

	@overload
	def isBurnable(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state is burnable. 
		"""
		pass

	@overload
	def isLiquid(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state is a liquid. 
		"""
		pass

	@overload
	def isSolid(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the state is solid. 
		"""
		pass

	@overload
	def isReplaceable(self) -> bool:
		"""This will return true for blocks like air and grass, that can be replaced without breaking
them first.\n
		Since: 1.6.5 

		Returns:
			'true' if the state can be replaced. 
		"""
		pass

	@overload
	def allowsSpawning(self, pos: BlockPosHelper, entity: str) -> bool:
		"""
		Since: 1.6.5 

		Args:
			pos: the position of the block to check 
			entity: the entity type to check 

		Returns:
			'true' if the entity can spawn on this block state at the given position in the
current world. 
		"""
		pass

	@overload
	def shouldSuffocate(self, pos: BlockPosHelper) -> bool:
		"""
		Since: 1.6.5 

		Args:
			pos: the position of the block to check 

		Returns:
			'true' if an entity can suffocate in this block state at the given position in
the current world. 
		"""
		pass

	@overload
	def getUniversal(self) -> UniversalBlockStateHelper:
		"""
		Since: 1.8.4 

		Returns:
			an UniversalBlockStateHelper to access all properties of this block state. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper
from .BlockPosHelper import BlockPosHelper

net_minecraft_entity_decoration_EndCrystalEntity = TypeVar("net_minecraft_entity_decoration_EndCrystalEntity")
EndCrystalEntity = net_minecraft_entity_decoration_EndCrystalEntity


class EndCrystalEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: EndCrystalEntity) -> None:
		pass

	@overload
	def isNatural(self) -> bool:
		"""Naturally generated end crystals will have a bedrock base, while player placed ones will
not.\n
		Since: 1.8.4 

		Returns:
			'true' if the end crystal was not placed by a player, 'false' otherwise. 
		"""
		pass

	@overload
	def getBeamTarget(self) -> BlockPosHelper:
		"""
		Since: 1.8.4 

		Returns:
			the target of the crystal's beam, or 'null' if there is none. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper

net_minecraft_stat_StatHandler = TypeVar("net_minecraft_stat_StatHandler")
StatHandler = net_minecraft_stat_StatHandler

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class StatsHelper(BaseHelper):

	@overload
	def __init__(self, base: StatHandler) -> None:
		pass

	@overload
	def getStatList(self) -> List[str]:
		pass

	@overload
	def getStatText(self, statKey: str) -> Text:
		pass

	@overload
	def getRawStatValue(self, statKey: str) -> int:
		pass

	@overload
	def getFormattedStatValue(self, statKey: str) -> str:
		pass

	@overload
	def getFormattedStatMap(self) -> Mapping[str, str]:
		pass

	@overload
	def getRawStatMap(self) -> Mapping[str, int]:
		pass

	@overload
	def getEntityKilled(self, id: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the entity 

		Returns:
			how many times the player has killed the entity. 
		"""
		pass

	@overload
	def getKilledByEntity(self, id: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the entity 

		Returns:
			how many times the player has killed the specified entity. 
		"""
		pass

	@overload
	def getBlockMined(self, id: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the block 

		Returns:
			how many times the player has mined the block. 
		"""
		pass

	@overload
	def getItemBroken(self, id: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the item 

		Returns:
			how many times the player has broken the item. 
		"""
		pass

	@overload
	def getItemCrafted(self, id: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the item 

		Returns:
			how many times the player has crafted the item. 
		"""
		pass

	@overload
	def getItemUsed(self, id: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the item 

		Returns:
			how many times the player has used the item. 
		"""
		pass

	@overload
	def getItemPickedUp(self, id: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the item 

		Returns:
			how many times the player has picked up the item. 
		"""
		pass

	@overload
	def getItemDropped(self, id: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the item 

		Returns:
			how many times the player has dropped the item. 
		"""
		pass

	@overload
	def getCustomStat(self, id: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the custom stat 

		Returns:
			the value of the custom stat. 
		"""
		pass

	@overload
	def getCustomFormattedStat(self, id: str) -> str:
		"""
		Since: 1.8.4 

		Args:
			id: the identifier of the custom stat 

		Returns:
			the formatted value of the custom stat. 
		"""
		pass

	@overload
	def updateStatistics(self) -> "StatsHelper":
		"""Used to request an update of the statistics from the server.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .FChat import FChat
from .FPlayer import FPlayer
from .FRequest import FRequest
from .FJavaUtils import FJavaUtils
from .FKeyBind import FKeyBind
from .FHud import FHud
from .FTime import FTime
from .FJsMacros import FJsMacros
from .FFS import FFS
from .FReflection import FReflection
from .FUtils import FUtils
from .FClient import FClient
from .FWorld import FWorld
from .IFWrapper import IFWrapper
from .FGlobalVars import FGlobalVars
from .FPositionCommon import FPositionCommon

File = TypeVar("java.io.File")



Chat = FChat()
Player = FPlayer()
Request = FRequest()
JavaUtils = FJavaUtils()
KeyBind = FKeyBind()
Hud = FHud()
Time = FTime()
JsMacros = FJsMacros()
FS = FFS()
Reflection = FReflection()
Utils = FUtils()
Client = FClient()
World = FWorld()
JavaWrapper = IFWrapper()
GlobalVars = FGlobalVars()
PositionCommon = FPositionCommon()
context = EventContainer()
file = File()
event = BaseEvent()



from typing import overload
from typing import Mapping
from .BaseEvent import BaseEvent
from .MethodWrapper import MethodWrapper


class EventCustom(BaseEvent):
	"""Custom Events\n
	Since: 1.2.8 
	"""
	eventName: str
	joinable: bool
	cancelable: bool

	@overload
	def joinable(self) -> bool:
		pass

	@overload
	def cancellable(self) -> bool:
		pass

	@overload
	def __init__(self, eventName: str) -> None:
		"""

		Args:
			eventName: name of the event. please don't use an existing one... your scripts might not like that. 
		"""
		pass

	@overload
	def trigger(self) -> None:
		"""Triggers the event.
Try not to cause infinite looping by triggering the same EventCustom from its own listeners.\n
		Since: 1.2.8 
		"""
		pass

	@overload
	def triggerAsync(self, callback: MethodWrapper) -> None:
		"""trigger the event listeners, then run 'callback' when they finish.\n
		Since: 1.9.0 

		Args:
			callback: used as a Runnable , so no args, no return value. 
		"""
		pass

	@overload
	def putInt(self, name: str, i: int) -> int:
		"""Put an Integer into the event.\n
		Since: 1.2.8 

		Args:
			name: 
			i: 
		"""
		pass

	@overload
	def putString(self, name: str, str: str) -> str:
		"""put a String into the event.\n
		Since: 1.2.8 

		Args:
			str: 
			name: 
		"""
		pass

	@overload
	def putDouble(self, name: str, d: float) -> float:
		"""put a Double into the event.\n
		Since: 1.2.8 

		Args:
			d: 
			name: 
		"""
		pass

	@overload
	def putBoolean(self, name: str, b: bool) -> bool:
		"""put a Boolean into the event.\n
		Since: 1.2.8 

		Args:
			b: 
			name: 
		"""
		pass

	@overload
	def putObject(self, name: str, o: object) -> object:
		"""put anything else into the event.\n
		Since: 1.2.8 

		Args:
			name: 
			o: 
		"""
		pass

	@overload
	def getType(self, name: str) -> str:
		"""Returns the type of the defined item in the event as a string.\n
		Since: 1.2.8 

		Args:
			name: 
		"""
		pass

	@overload
	def getInt(self, name: str) -> int:
		"""Gets an Integer from the event.\n
		Since: 1.2.8 

		Args:
			name: 
		"""
		pass

	@overload
	def getString(self, name: str) -> str:
		"""Gets a String from the event\n
		Since: 1.2.8 

		Args:
			name: 
		"""
		pass

	@overload
	def getDouble(self, name: str) -> float:
		"""Gets a Double from the event.\n
		Since: 1.2.8 

		Args:
			name: 
		"""
		pass

	@overload
	def getBoolean(self, name: str) -> bool:
		"""Gets a Boolean from the event.\n
		Since: 1.2.8 

		Args:
			name: 
		"""
		pass

	@overload
	def getObject(self, name: str) -> object:
		"""Gets an Object from the event.\n
		Since: 1.2.8 

		Args:
			name: 
		"""
		pass

	@overload
	def getUnderlyingMap(self) -> Mapping[str, object]:
		"""
		Since: 1.6.4 

		Returns:
			map backing the event 
		"""
		pass

	@overload
	def registerEvent(self) -> None:
		"""registers event so you can see it in the gui\n
		Since: 1.3.0 
		"""
		pass

	pass





from typing import overload
from .EventFilterer import EventFilterer
from .BaseEvent import BaseEvent


class FiltererModulus(EventFilterer):
	"""
	Since: 1.9.1 
	"""
	quotient: int
	count: int

	@overload
	def __init__(self, quotient: int) -> None:
		pass

	@overload
	def canFilter(self, event: str) -> bool:
		pass

	@overload
	def test(self, event: BaseEvent) -> bool:
		pass

	@overload
	def setQuotient(self, quotient: int) -> "FiltererModulus":
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper
from .BlockPosHelper import BlockPosHelper

net_minecraft_entity_passive_DolphinEntity = TypeVar("net_minecraft_entity_passive_DolphinEntity")
DolphinEntity = net_minecraft_entity_passive_DolphinEntity


class DolphinEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: DolphinEntity) -> None:
		pass

	@overload
	def hasFish(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the dolphin has a fish in its mouth, 'false' otherwise. 
		"""
		pass

	@overload
	def getTreasurePos(self) -> BlockPosHelper:
		"""The position will be 0 0 0 by default.\n
		Since: 1.8.4 

		Returns:
			the position of the treasure the dolphin is looking for. 
		"""
		pass

	@overload
	def getMoistness(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the moisture level of the dolphin. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .Draw3D import Draw3D
from .PlayerInput import PlayerInput

net_minecraft_client_network_ClientPlayerEntity = TypeVar("net_minecraft_client_network_ClientPlayerEntity")
ClientPlayerEntity = net_minecraft_client_network_ClientPlayerEntity


class MovementQueue:
	predPoints: Draw3D

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def tick(self, newPlayer: ClientPlayerEntity) -> PlayerInput:
		pass

	@overload
	def append(self, input: PlayerInput, newPlayer: ClientPlayerEntity) -> None:
		pass

	@overload
	def setDrawPredictions(self, val: bool) -> None:
		pass

	@overload
	def clear(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Set
from .Core import Core
from .BaseEventRegistry import BaseEventRegistry
from .BaseEvent import BaseEvent

java_lang_Throwable = TypeVar("java_lang_Throwable")
Throwable = java_lang_Throwable

org_slf4j_Logger = TypeVar("org_slf4j_Logger")
Logger = org_slf4j_Logger

java_lang_Thread = TypeVar("java_lang_Thread")
Thread = java_lang_Thread


class BaseProfile:
	"""
	Since: 1.2.7 
	"""
	LOGGER: Logger
	joinedThreadStack: Set[Thread]
	events: Set[str]
	profileName: str

	@overload
	def __init__(self, runner: Core, logger: Logger) -> None:
		pass

	@overload
	def logError(self, ex: Throwable) -> None:
		pass

	@overload
	def getRegistry(self) -> BaseEventRegistry:
		"""
		Since: 1.1.2 [citation needed] 
		"""
		pass

	@overload
	def checkJoinedThreadStack(self) -> bool:
		"""
		Since: 1.6.0 
		"""
		pass

	@overload
	def loadOrCreateProfile(self, profileName: str) -> None:
		"""
		Since: 1.1.2 [citation needed] 

		Args:
			profileName: 
		"""
		pass

	@overload
	def saveProfile(self) -> None:
		"""
		Since: 1.0.8 [citation needed] 
		"""
		pass

	@overload
	def triggerEvent(self, event: BaseEvent) -> None:
		"""
		Since: 1.2.7 

		Args:
			event: 
		"""
		pass

	@overload
	def init(self, defaultProfile: str) -> None:
		pass

	@overload
	def getCurrentProfileName(self) -> str:
		pass

	@overload
	def renameCurrentProfile(self, profile: str) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .OptionsHelper import OptionsHelper

net_minecraft_client_option_KeyBinding = TypeVar("net_minecraft_client_option_KeyBinding")
KeyBinding = net_minecraft_client_option_KeyBinding


class OptionsHelper_ControlOptionsHelper:
	parent: OptionsHelper

	@overload
	def __init__(self, OptionsHelper: OptionsHelper) -> None:
		pass

	@overload
	def getParent(self) -> OptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			the parent options helper. 
		"""
		pass

	@overload
	def getMouseSensitivity(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current mouse sensitivity. 
		"""
		pass

	@overload
	def setMouseSensitivity(self, val: float) -> "OptionsHelper_ControlOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new mouse sensitivity 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isMouseInverted(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the mouse direction should be inverted. 
		"""
		pass

	@overload
	def invertMouse(self, val: bool) -> "OptionsHelper_ControlOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to invert the mouse direction or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getMouseWheelSensitivity(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current mouse wheel sensitivity. 
		"""
		pass

	@overload
	def setMouseWheelSensitivity(self, val: float) -> "OptionsHelper_ControlOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new mouse wheel sensitivity 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isDiscreteScrollingEnabled(self) -> bool:
		"""This option was introduced due to a bug on some systems where the mouse wheel would
scroll too fast.\n
		Since: 1.8.4 

		Returns:
			'true' if discrete scrolling is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def enableDiscreteScrolling(self, val: bool) -> "OptionsHelper_ControlOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable discrete scrolling or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isTouchscreenEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if touchscreen mode is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def enableTouchscreen(self, val: bool) -> "OptionsHelper_ControlOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable touchscreen mode or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRawMouseInputEnabled(self) -> bool:
		"""Raw input is directly reading the mouse data, without any adjustments due to other
programs or the operating system.\n
		Since: 1.8.4 

		Returns:
			'true' if raw mouse input is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def enableRawMouseInput(self, val: bool) -> "OptionsHelper_ControlOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable raw mouse input or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isAutoJumpEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if auto jump is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def enableAutoJump(self, val: bool) -> "OptionsHelper_ControlOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable auto jump or not or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isSneakTogglingEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the toggle functionality for sneaking is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def toggleSneak(self, val: bool) -> "OptionsHelper_ControlOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable or disable the toggle functionality for sneaking 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isSprintTogglingEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the toggle functionality for sprinting is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def toggleSprint(self, val: bool) -> "OptionsHelper_ControlOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable or disable the toggle functionality for sprinting 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRawKeys(self) -> List[KeyBinding]:
		"""
		Since: 1.8.4 

		Returns:
			an array of all raw minecraft keybindings. 
		"""
		pass

	@overload
	def getCategories(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all keybinding categories. 
		"""
		pass

	@overload
	def getKeys(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all key names. 
		"""
		pass

	@overload
	def getKeyBinds(self) -> Mapping[str, str]:
		"""
		Since: 1.8.4 

		Returns:
			a map of all keybindings and their bound key. 
		"""
		pass

	@overload
	def getKeyBindsByCategory(self, category: str) -> Mapping[str, str]:
		"""
		Since: 1.8.4 

		Args:
			category: the category to get keybindings from 

		Returns:
			a map of all keybindings and their bound key in the specified category. 
		"""
		pass

	@overload
	def getKeyBindsByCategory(self) -> Mapping[str, Mapping[str, str]]:
		"""
		Since: 1.8.4 

		Returns:
			a map of all keybinding categories, containing a map of all keybindings in that
category and their bound key. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseScreen import BaseScreen
from .ScriptTrigger import ScriptTrigger
from .MultiElementContainer import MultiElementContainer
from .MacroContainer import MacroContainer

net_minecraft_client_gui_screen_Screen = TypeVar("net_minecraft_client_gui_screen_Screen")
Screen = net_minecraft_client_gui_screen_Screen

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

java_io_File = TypeVar("java_io_File")
File = java_io_File


class MacroScreen(BaseScreen):

	@overload
	def __init__(self, parent: Screen) -> None:
		pass

	@overload
	def mouseScrolled(self, mouseX: float, mouseY: float, horiz: float, vert: float) -> bool:
		pass

	@overload
	def addMacro(self, macro: ScriptTrigger) -> None:
		pass

	@overload
	def setFile(self, macro: MultiElementContainer) -> None:
		pass

	@overload
	def setEvent(self, macro: MacroContainer) -> None:
		pass

	@overload
	def runFile(self) -> None:
		pass

	@overload
	def confirmRemoveMacro(self, macro: MultiElementContainer) -> None:
		pass

	@overload
	def removeMacro(self, macro: MultiElementContainer) -> None:
		pass

	@overload
	def setMacroPos(self) -> None:
		pass

	@overload
	def editFile(self, file: File) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def updateSettings(self) -> None:
		pass

	@overload
	def removed(self) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .ChatHudLineHelper import ChatHudLineHelper
from .TextHelper import TextHelper
from .MethodWrapper import MethodWrapper

net_minecraft_client_gui_hud_ChatHud = TypeVar("net_minecraft_client_gui_hud_ChatHud")
ChatHud = net_minecraft_client_gui_hud_ChatHud


class ChatHistoryManager:
	"""
	Since: 1.6.0 
	"""

	@overload
	def __init__(self, hud: ChatHud) -> None:
		pass

	@overload
	def getRecvLine(self, index: int) -> ChatHudLineHelper:
		"""
		Since: 1.6.0 

		Args:
			index: 
		"""
		pass

	@overload
	def getRecvCount(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the amount of messages in the chat history. 
		"""
		pass

	@overload
	def getRecvLines(self) -> List[ChatHudLineHelper]:
		"""
		Since: 1.8.4 

		Returns:
			all received messages in the chat history. 
		"""
		pass

	@overload
	def insertRecvText(self, index: int, line: TextHelper) -> None:
		"""
		Since: 1.6.0 

		Args:
			line: 
			index: 
		"""
		pass

	@overload
	def insertRecvText(self, index: int, line: TextHelper, timeTicks: int) -> None:
		"""you should probably run ChatHistoryManager#refreshVisible() after...\n
		Since: 1.6.0 

		Args:
			line: 
			timeTicks: 
			index: 
		"""
		pass

	@overload
	def insertRecvText(self, index: int, line: TextHelper, timeTicks: int, await_: bool) -> None:
		"""
		Since: 1.6.0 

		Args:
			line: 
			timeTicks: 
			await: 
			index: 
		"""
		pass

	@overload
	def removeRecvText(self, index: int) -> None:
		"""
		Since: 1.6.0 

		Args:
			index: 
		"""
		pass

	@overload
	def removeRecvText(self, index: int, await_: bool) -> None:
		"""
		Since: 1.6.0 

		Args:
			await: 
			index: 
		"""
		pass

	@overload
	def removeRecvTextMatching(self, text: TextHelper) -> None:
		"""
		Since: 1.6.0 

		Args:
			text: 
		"""
		pass

	@overload
	def removeRecvTextMatching(self, text: TextHelper, await_: bool) -> None:
		"""
		Since: 1.6.0 

		Args:
			await: 
			text: 
		"""
		pass

	@overload
	def removeRecvTextMatchingFilter(self, filter: MethodWrapper) -> None:
		"""
		Since: 1.6.0 

		Args:
			filter: 
		"""
		pass

	@overload
	def removeRecvTextMatchingFilter(self, filter: MethodWrapper, await_: bool) -> None:
		"""
		Since: 1.6.0 

		Args:
			filter: 
			await: 
		"""
		pass

	@overload
	def refreshVisible(self) -> None:
		"""this will reset the view of visible messages\n
		Since: 1.6.0 
		"""
		pass

	@overload
	def refreshVisible(self, await_: bool) -> None:
		"""
		Since: 1.6.0 

		Args:
			await: 
		"""
		pass

	@overload
	def clearRecv(self) -> None:
		"""
		Since: 1.6.0 
		"""
		pass

	@overload
	def clearRecv(self, await_: bool) -> None:
		"""
		Since: 1.6.0 

		Args:
			await: 
		"""
		pass

	@overload
	def getSent(self) -> List[str]:
		"""
		Since: 1.6.0 

		Returns:
			direct reference to sent message history list. modifications will affect the list. 
		"""
		pass

	@overload
	def clearSent(self) -> None:
		"""
		Since: 1.6.0 
		"""
		pass

	@overload
	def clearSent(self, await_: bool) -> None:
		"""
		Since: 1.6.0 

		Args:
			await: 
		"""
		pass

	pass





from typing import overload
from typing import List
from .ClassBuilder import ClassBuilder
from .MethodWrapper import MethodWrapper
from .ClassBuilder_BodyBuilder import ClassBuilder_BodyBuilder
from .ClassBuilder_AnnotationBuilder import ClassBuilder_AnnotationBuilder


class ClassBuilder_MethodBuilder:

	@overload
	def __init__(self, methodReturnType: CtClass, methodName: str, params: List[CtClass]) -> None:
		pass

	@overload
	def compile(self, code: str) -> "ClassBuilder":
		pass

	@overload
	def makePrivate(self) -> "ClassBuilder_MethodBuilder":
		pass

	@overload
	def makePublic(self) -> "ClassBuilder_MethodBuilder":
		pass

	@overload
	def makeProtected(self) -> "ClassBuilder_MethodBuilder":
		pass

	@overload
	def makePackagePrivate(self) -> "ClassBuilder_MethodBuilder":
		pass

	@overload
	def toggleStatic(self) -> "ClassBuilder_MethodBuilder":
		pass

	@overload
	def rename(self, newName: str) -> "ClassBuilder_MethodBuilder":
		pass

	@overload
	def exceptions(self, exceptions: List[Class]) -> "ClassBuilder_MethodBuilder":
		pass

	@overload
	def body(self, code_src: str) -> "ClassBuilder":
		pass

	@overload
	def guestBody(self, methodBody: MethodWrapper) -> "ClassBuilder":
		pass

	@overload
	def buildBody(self) -> "ClassBuilder_BodyBuilder":
		pass

	@overload
	def body(self, buildBody: MethodWrapper) -> "ClassBuilder":
		pass

	@overload
	def endAbstract(self) -> "ClassBuilder":
		pass

	@overload
	def addAnnotation(self, type: Class) -> "ClassBuilder_AnnotationBuilder":
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .GroupFilter import GroupFilter

T = TypeVar("T")

class GroupFilter_NoneMatchFilter(Generic[T], GroupFilter):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def apply(self, t: T) -> bool:
		pass

	pass





from typing import overload
from typing import Mapping
from .EventFilterer import EventFilterer
from .BlockPosHelper import BlockPosHelper
from .BaseEvent import BaseEvent


class FiltererBlockUpdate(EventFilterer):
	"""
	Since: 1.9.1 
	"""
	pos: BlockPosHelper
	pos2: BlockPosHelper
	blockId: str
	blockState: Mapping[str, str]
	updateType: str

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def canFilter(self, event: str) -> bool:
		pass

	@overload
	def test(self, baseEvent: BaseEvent) -> bool:
		pass

	@overload
	def setPos(self, x: int, y: int, z: int) -> "FiltererBlockUpdate":
		pass

	@overload
	def setPos(self, pos: BlockPosHelper) -> "FiltererBlockUpdate":
		pass

	@overload
	def setArea(self, x1: int, y1: int, z1: int, x2: int, y2: int, z2: int) -> "FiltererBlockUpdate":
		pass

	@overload
	def setArea(self, pos1: BlockPosHelper, pos2: BlockPosHelper) -> "FiltererBlockUpdate":
		pass

	@overload
	def setBlockId(self, id: str) -> "FiltererBlockUpdate":
		pass

	@overload
	def setUpdateType(self, type: str) -> "FiltererBlockUpdate":
		pass

	@overload
	def setBlockStates(self, states: Mapping[str, str]) -> "FiltererBlockUpdate":
		pass

	@overload
	def setBlockState(self, property: str, value: str) -> "FiltererBlockUpdate":
		"""

		Args:
			value: setting to null will make sure the block doesn't have this property 
		"""
		pass

	pass





from typing import overload
from typing import List
from .Inventory import Inventory
from .TradeOfferHelper import TradeOfferHelper


class VillagerInventory(Inventory):
	"""
	Since: 1.3.1 
	"""

	@overload
	def selectTrade(self, index: int) -> "VillagerInventory":
		"""select the trade by its index\n
		Since: 1.3.1 

		Args:
			index: 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def getExperience(self) -> int:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def getLevelProgress(self) -> int:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def getMerchantRewardedExperience(self) -> int:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def canRefreshTrades(self) -> bool:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def isLeveled(self) -> bool:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def getTrades(self) -> List[TradeOfferHelper]:
		"""
		Since: 1.3.1 

		Returns:
			list of trade offers 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import Mapping
from .Library import Library
from .BaseLibrary import BaseLibrary
from .PerLanguageLibrary import PerLanguageLibrary
from .BaseLanguage import BaseLanguage
from .BaseScriptContext import BaseScriptContext


class LibraryRegistry:
	libraries: Mapping[Library, BaseLibrary]
	perExec: Mapping[Library, Class]
	perLanguage: Mapping[Class, Mapping[Library, PerLanguageLibrary]]
	perExecLanguage: Mapping[Class, Mapping[Library, Class]]

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getLibraries(self, language: BaseLanguage, context: BaseScriptContext) -> Mapping[str, BaseLibrary]:
		pass

	@overload
	def getOnceLibraries(self, language: BaseLanguage) -> Mapping[str, BaseLibrary]:
		pass

	@overload
	def getPerExecLibraries(self, language: BaseLanguage, context: BaseScriptContext) -> Mapping[str, BaseLibrary]:
		pass

	@overload
	def addLibrary(self, clazz: Class) -> None:
		pass

	pass





from typing import overload
from .ClickableWidgetHelper import ClickableWidgetHelper
from .Slider import Slider


class SliderWidgetHelper(ClickableWidgetHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, btn: Slider) -> None:
		pass

	@overload
	def __init__(self, btn: Slider, zIndex: int) -> None:
		pass

	@overload
	def getValue(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current value of this slider. 
		"""
		pass

	@overload
	def setValue(self, value: float) -> "SliderWidgetHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the new value 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getSteps(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the set amount of steps of this slider. 
		"""
		pass

	@overload
	def setSteps(self, steps: int) -> "SliderWidgetHelper":
		"""
		Since: 1.8.4 

		Args:
			steps: the amount of steps 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import Set
from .NBTElementHelper import NBTElementHelper


class NBTElementHelper_NBTCompoundHelper(NBTElementHelper):
	"""
	Since: 1.5.1 
	"""

	@overload
	def getKeys(self) -> Set[str]:
		"""
		Since: 1.6.0 
		"""
		pass

	@overload
	def getType(self, key: str) -> int:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def has(self, key: str) -> bool:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def get(self, key: str) -> NBTElementHelper:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def asString(self, key: str) -> str:
		"""
		Since: 1.5.1 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

net_minecraft_util_Formatting = TypeVar("net_minecraft_util_Formatting")
Formatting = net_minecraft_util_Formatting


class FormattingHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: Formatting) -> None:
		pass

	@overload
	def getColorValue(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color value of this formatting. 
		"""
		pass

	@overload
	def getColorIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the index of this formatting or '-1' if this formatting is a modifier. 
		"""
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of this formatting. 
		"""
		pass

	@overload
	def getCode(self) -> str:
		"""The color code can be used with the paragraph to color text.\n
		Since: 1.8.4 

		Returns:
			the color code of this formatting. 
		"""
		pass

	@overload
	def isColor(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this formatting is a color, 'false' otherwise. 
		"""
		pass

	@overload
	def isModifier(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this formatting is a modifier, 'false' otherwise. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .OverlayContainer import OverlayContainer
from .IOverlayParent import IOverlayParent

java_util_function_Consumer_java_lang_String_ = TypeVar("java_util_function_Consumer_java_lang_String_")
Consumer = java_util_function_Consumer_java_lang_String_

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class EventChooser(OverlayContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, selected: str, parent: IOverlayParent, setEvent: Consumer) -> None:
		pass

	@overload
	def selectEvent(self, event: str) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def addEvent(self, eventName: str) -> None:
		pass

	@overload
	def updateEventPos(self) -> None:
		pass

	@overload
	def onScrollbar(self, page: float) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper
from .TeamHelper import TeamHelper

net_minecraft_client_network_PlayerListEntry = TypeVar("net_minecraft_client_network_PlayerListEntry")
PlayerListEntry = net_minecraft_client_network_PlayerListEntry


class PlayerListEntryHelper(BaseHelper):
	"""
	Since: 1.0.2 
	"""

	@overload
	def __init__(self, p: PlayerListEntry) -> None:
		pass

	@overload
	def getUUID(self) -> str:
		"""
		Since: 1.1.9 
		"""
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.0.2 
		"""
		pass

	@overload
	def getPing(self) -> int:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getGamemode(self) -> str:
		"""
		Since: 1.6.5 

		Returns:
			null if unknown 
		"""
		pass

	@overload
	def getDisplayText(self) -> TextHelper:
		"""
		Since: 1.1.9 
		"""
		pass

	@overload
	def getPublicKey(self) -> List[float]:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def hasCape(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player has a cape enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def hasSlimModel(self) -> bool:
		"""A slim skin is an Alex skin, while the default one is Steve.\n
		Since: 1.8.4 

		Returns:
			'true' if the player has a slim skin, 'false' otherwise. 
		"""
		pass

	@overload
	def getSkinTexture(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the identifier of the player's skin texture or 'null' if it's unknown. 
		"""
		pass

	@overload
	def getSkinUrl(self) -> str:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def getCapeTexture(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the identifier of the player's cape texture or 'null' if it's unknown. 
		"""
		pass

	@overload
	def getElytraTexture(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the identifier of the player's elytra texture or 'null' if it's unknown. 
		"""
		pass

	@overload
	def getTeam(self) -> TeamHelper:
		"""
		Since: 1.8.4 

		Returns:
			the team of the player or 'null' if the player is not in a team. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .BasicFilter import BasicFilter
from .IFilter import IFilter

T = TypeVar("T")

class ClassWrapperFilter(Generic[T], BasicFilter):
	"""
	Since: 1.6.5 
	"""

	@overload
	def getFilter(self, clazz: Class, methodName: str, args: List[object]) -> IFilter:
		pass

	@overload
	def apply(self, t: T) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .ClickableWidgetHelper import ClickableWidgetHelper

T = TypeVar("T")
net_minecraft_client_gui_widget_CyclingButtonWidget_T_ = TypeVar("net_minecraft_client_gui_widget_CyclingButtonWidget_T_")
CyclingButtonWidget = net_minecraft_client_gui_widget_CyclingButtonWidget_T_


class CyclingButtonWidgetHelper(Generic[T], ClickableWidgetHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, btn: CyclingButtonWidget) -> None:
		pass

	@overload
	def __init__(self, btn: CyclingButtonWidget, zIndex: int) -> None:
		pass

	@overload
	def getValue(self) -> T:
		"""
		Since: 1.8.4 

		Returns:
			the current value. 
		"""
		pass

	@overload
	def getStringValue(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the current value in their string representation. 
		"""
		pass

	@overload
	def setValue(self, val: T) -> bool:
		"""
		Since: 1.8.4 

		Args:
			val: the new value 

		Returns:
			'true' if the value has changed, 'false' otherwise. 
		"""
		pass

	@overload
	def cycle(self, amount: int) -> "CyclingButtonWidgetHelper":
		"""
		Since: 1.8.4 

		Args:
			amount: the amount to cycle by 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def forward(self) -> "CyclingButtonWidgetHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def backward(self) -> "CyclingButtonWidgetHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

R = TypeVar("R")

class Registrable:
	"""
	Since: 1.9.1 
	"""

	@overload
	def register(self) -> R:
		pass

	@overload
	def unregister(self) -> R:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper
from .ItemStackHelper import ItemStackHelper
from .EntityHelper import EntityHelper

net_minecraft_entity_passive_FoxEntity = TypeVar("net_minecraft_entity_passive_FoxEntity")
FoxEntity = net_minecraft_entity_passive_FoxEntity


class FoxEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: FoxEntity) -> None:
		pass

	@overload
	def getItemInMouth(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the item in this fox's mouth. 
		"""
		pass

	@overload
	def isSnowFox(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is a snow fox, 'false' otherwise. 
		"""
		pass

	@overload
	def isRedFox(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is a red fox, 'false' otherwise. 
		"""
		pass

	@overload
	def getOwner(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the owner's UUID, or 'null' if this fox has no owner. 
		"""
		pass

	@overload
	def getSecondOwner(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the second owner's name, or 'null' if this fox has no owner. 
		"""
		pass

	@overload
	def canTrust(self, entity: EntityHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			entity: the entity to check 

		Returns:
			'true' if this fox trusts the given entity, 'false' otherwise. 
		"""
		pass

	@overload
	def hasFoundTarget(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is preparing its jump, 'false' otherwise. 
		"""
		pass

	@overload
	def isSitting(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is sitting, 'false' otherwise. 
		"""
		pass

	@overload
	def isWandering(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is wandering around, 'false' otherwise. 
		"""
		pass

	@overload
	def isSleeping(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is sleeping, 'false' otherwise. 
		"""
		pass

	@overload
	def isDefending(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is defending another fox, 'false' otherwise. 
		"""
		pass

	@overload
	def isPouncing(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is just before its leap, 'false' otherwise. 
		"""
		pass

	@overload
	def isJumping(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is jumping, 'false' otherwise. 
		"""
		pass

	@overload
	def isSneaking(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this fox is sneaking in preparation of an attack, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from .BaseProfile import BaseProfile


class BaseEvent:
	profile: BaseProfile

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def cancellable(self) -> bool:
		pass

	@overload
	def joinable(self) -> bool:
		pass

	@overload
	def cancel(self) -> None:
		pass

	@overload
	def isCanceled(self) -> bool:
		pass

	@overload
	def getEventName(self) -> str:
		pass

	@overload
	def trigger(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo

net_minecraft_client_sound_SoundInstance = TypeVar("net_minecraft_client_sound_SoundInstance")
SoundInstance = net_minecraft_client_sound_SoundInstance


class MixinSoundSystem:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onPlay(self, instance: SoundInstance, info: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_util_math_MatrixStack = TypeVar("net_minecraft_client_util_math_MatrixStack")
MatrixStack = net_minecraft_client_util_math_MatrixStack

net_minecraft_client_MinecraftClient = TypeVar("net_minecraft_client_MinecraftClient")
MinecraftClient = net_minecraft_client_MinecraftClient

net_minecraft_client_gui_Drawable = TypeVar("net_minecraft_client_gui_Drawable")
Drawable = net_minecraft_client_gui_Drawable


class RenderElement(Drawable):
	"""
	"""
	mc: MinecraftClient

	@overload
	def getZIndex(self) -> int:
		pass

	@overload
	def render3D(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def setupMatrix(self, matrices: MatrixStack, x: float, y: float, scale: float, rotation: float) -> None:
		pass

	@overload
	def setupMatrix(self, matrices: MatrixStack, x: float, y: float, scale: float, rotation: float, width: float, height: float, rotateAroundCenter: bool) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper

net_minecraft_entity_AreaEffectCloudEntity = TypeVar("net_minecraft_entity_AreaEffectCloudEntity")
AreaEffectCloudEntity = net_minecraft_entity_AreaEffectCloudEntity


class AreaEffectCloudEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, e: AreaEffectCloudEntity) -> None:
		pass

	@overload
	def getRadius(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the radius of this cloud. 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of this cloud. 
		"""
		pass

	@overload
	def getParticleType(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the id of this cloud's particles. 
		"""
		pass

	@overload
	def isWaiting(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .PerExecLibrary import PerExecLibrary
from .FReflection_CombinedVariableClassLoader import FReflection_CombinedVariableClassLoader
from .BaseScriptContext import BaseScriptContext
from .ProxyBuilder import ProxyBuilder
from .ClassBuilder import ClassBuilder
from .LibraryBuilder import LibraryBuilder
from .Mappings import Mappings
from .WrappedClassInstance import WrappedClassInstance

java_lang_reflect_Field = TypeVar("java_lang_reflect_Field")
Field = java_lang_reflect_Field

T = TypeVar("T")
org_joor_Reflect = TypeVar("org_joor_Reflect")
Reflect = org_joor_Reflect

java_lang_reflect_Method = TypeVar("java_lang_reflect_Method")
Method = java_lang_reflect_Method


class FReflection(PerExecLibrary):
	"""Functions for getting and using raw java classes, methods and functions. 
An instance of this class is passed to scripts as the 'Reflection' variable.\n
	Since: 1.2.3 
	"""
	classLoader: FReflection_CombinedVariableClassLoader

	@overload
	def __init__(self, context: BaseScriptContext) -> None:
		pass

	@overload
	def getClass(self, name: str) -> Class:
		"""
		Since: 1.2.3 

		Args:
			name: name of class like 'path.to.class' 

		Returns:
			resolved class 
		"""
		pass

	@overload
	def getClass(self, name: str, name2: str) -> Class:
		"""Use this to specify a class with intermediary and yarn names of classes for cleaner code. also has support for
java primitives by using their name in lower case.\n
		Since: 1.2.3 

		Args:
			name: first try 
			name2: second try 

		Returns:
			a Class reference. 
		"""
		pass

	@overload
	def getDeclaredMethod(self, c: Class, name: str, parameterTypes: List[Class]) -> Method:
		"""
		Since: 1.2.3 

		Args:
			c: 
			parameterTypes: 
			name: 
		"""
		pass

	@overload
	def getDeclaredMethod(self, c: Class, name: str, name2: str, parameterTypes: List[Class]) -> Method:
		"""Use this to specify a method with intermediary and yarn names of classes for cleaner code.\n
		Since: 1.2.3 

		Args:
			c: 
			parameterTypes: 
			name: 
			name2: 

		Returns:
			a Method reference. 
		"""
		pass

	@overload
	def getMethod(self, c: Class, name: str, name2: str, parameterTypes: List[Class]) -> Method:
		"""
		Since: 1.6.0 

		Args:
			c: 
			parameterTypes: 
			name: 
			name2: 
		"""
		pass

	@overload
	def getMethod(self, c: Class, name: str, parameterTypes: List[Class]) -> Method:
		"""
		Since: 1.6.0 

		Args:
			c: 
			parameterTypes: 
			name: 
		"""
		pass

	@overload
	def getDeclaredField(self, c: Class, name: str) -> Field:
		"""
		Since: 1.2.3 

		Args:
			c: 
			name: 
		"""
		pass

	@overload
	def getDeclaredField(self, c: Class, name: str, name2: str) -> Field:
		"""Use this to specify a field with intermediary and yarn names of classes for cleaner code.\n
		Since: 1.2.3 

		Args:
			c: 
			name: 
			name2: 

		Returns:
			a Field reference. 
		"""
		pass

	@overload
	def getField(self, c: Class, name: str) -> Field:
		"""
		Since: 1.6.0 

		Args:
			c: 
			name: 
		"""
		pass

	@overload
	def getField(self, c: Class, name: str, name2: str) -> Field:
		"""
		Since: 1.6.0 

		Args:
			c: 
			name: 
			name2: 
		"""
		pass

	@overload
	def invokeMethod(self, m: Method, c: object, objects: List[object]) -> object:
		"""Invoke a method on an object with auto type coercion for numbers.\n
		Since: 1.2.3 

		Args:
			c: object (can be 'null' for statics) 
			objects: 
			m: method 
		"""
		pass

	@overload
	def newInstance(self, c: Class, objects: List[object]) -> T:
		"""Attempts to create a new instance of a class. You probably don't have to use this one and can just call '
new' on a Class unless you're in LUA, but then you also have the (kinda poorly
documented, can someone find a better docs link for me) LuaJava Library .\n
		Since: 1.2.7 

		Args:
			c: 
			objects: 
		"""
		pass

	@overload
	def createClassProxyBuilder(self, clazz: Class, interfaces: List[Class]) -> ProxyBuilder:
		"""proxy for extending java classes in the guest language with proper threading support.\n
		Since: 1.6.0 

		Args:
			interfaces: 
			T: 
			clazz: 
		"""
		pass

	@overload
	def createClassBuilder(self, cName: str, clazz: Class, interfaces: List[Class]) -> ClassBuilder:
		"""
		Since: 1.6.5 

		Args:
			interfaces: 
			T: 
			cName: 
			clazz: 
		"""
		pass

	@overload
	def getClassFromClassBuilderResult(self, cName: str) -> Class:
		"""
		Since: 1.6.5 

		Args:
			cName: 
		"""
		pass

	@overload
	def createLibraryBuilder(self, name: str, perExec: bool, acceptedLangs: List[str]) -> LibraryBuilder:
		pass

	@overload
	def createLibrary(self, className: str, javaCode: str) -> None:
		"""A library class always has a Library annotation containing the name of the library,
which may differ from the actual class name. A library class must also extend BaseLibrary in some way, either directly or through PerExecLibrary , PerExecLanguageLibrary or PerLanguageLibrary .\n
		Since: 1.8.4 

		Args:
			javaCode: the source code of the library 
			className: the fully qualified name of the class, including the package 
		"""
		pass

	@overload
	def compileJavaClass(self, className: str, code: str) -> Class:
		"""A Java Development Kit (JDK) must be installed (and potentially used to start Minecraft) in
order to compile whole classes. 
Compiled classes can't be accessed from any guest language, but must be either stored through FGlobalVars#putObject(java.lang.String,java.lang.Object) or retrieved from this library. Unlike normal
hot swapping, already created instances of the class will not be updated. Thus, it's
important to know which version of the class you're using when instantiating it.\n
		Since: 1.8.4 

		Args:
			code: the java code to compile 
			className: the fully qualified name of the class, including the package 

		Returns:
			the compiled class. 
		"""
		pass

	@overload
	def getCompiledJavaClass(self, className: str) -> Class:
		"""
		Since: 1.8.4 

		Args:
			className: the fully qualified name of the class, including the package 

		Returns:
			the latest compiled class or 'null' if it doesn't exist. 
		"""
		pass

	@overload
	def getAllCompiledJavaClassVersions(self, className: str) -> List[Class]:
		"""
		Since: 1.8.4 

		Args:
			className: the fully qualified name of the class, including the package 

		Returns:
			all compiled versions of the class, in order of compilation. 
		"""
		pass

	@overload
	def getReflect(self, obj: object) -> Reflect:
		"""See jOOR Github for more information.\n
		Since: 1.8.4 

		Args:
			obj: the object to wrap 

		Returns:
			a wrapper for the passed object to do help with java reflection. 
		"""
		pass

	@overload
	def loadJarFile(self, file: str) -> bool:
		"""Loads a jar file to be accessible with this library.\n
		Since: 1.2.6 

		Args:
			file: relative to the script's folder. 

		Returns:
			success value 
		"""
		pass

	@overload
	def loadCurrentMappingHelper(self) -> Mappings:
		"""
		Since: 1.3.1 

		Returns:
			the previous mapping helper generated with FReflection#loadMappingHelper(java.lang.String) 
		"""
		pass

	@overload
	def getClassName(self, o: object) -> str:
		"""
		Since: 1.3.1 

		Args:
			o: class you want the name of 

		Returns:
			the fully qualified class name (with "."'s not "/"'s) 
		"""
		pass

	@overload
	def loadMappingHelper(self, urlorfile: str) -> Mappings:
		"""
		Since: 1.3.1 

		Args:
			urlorfile: a url or file path the the yarn mappings '-v2.jar' file, or '.tiny' file. for example 'https://maven.fabricmc.net/net/fabricmc/yarn/1.16.5%2Bbuild.3/yarn-1.16.5%2Bbuild.3-v2.jar' , if same url/path as previous this will load from cache. 

		Returns:
			the associated mapping helper. 
		"""
		pass

	@overload
	def wrapInstace(self, instance: T) -> WrappedClassInstance:
		"""
		Since: 1.6.5 

		Args:
			instance: 
			T: 
		"""
		pass

	@overload
	def getWrappedClass(self, className: str) -> WrappedClassInstance:
		"""
		Since: 1.6.5 

		Args:
			className: 
		"""
		pass

	pass





from typing import overload
from typing import List
from .WorldScanner import WorldScanner


class WorldScannerBuilder:
	"""The builder can be used to create a world scanner with native java functions. This is especially useful for languages like javascript that
don't support multithreading, which causes streams to run sequential instead of parallel.
The builder has two filters for the block and the block state, which need to be configured separately.
If one function is not defined, it will just be ignored when building the scanner. The block and block state filters have to start with a 'with' command like WorldScannerBuilder#withStateFilter(java.lang.String) or WorldScannerBuilder#withStringBlockFilter() .
This will overwrite all previous filters of the same type. To add more commands, it's possible to use commands with the prefix 'and', 'or', 'xor'.
The 'not' command will just negate the whole block or block state filter and doesn't need any arguments.  
All other commands need some arguments to work. For String functions, it's one of these functions: 'equals', 'contains', 'startsWith', 'endsWith' or 'matches'.
The strings to match are passed as vararg parameters (as many as needed, separated by a comma 'is("chest", "barrel", "ore"' ) and the filter acts
like a logical or, so only one of the arguments needs to match the criteria. It should be noted, that string functions call the toString method, so
comparing a block with something like "minecraft:stone" will always return false, because the toString method gives "{minecraft:stone}". For doing this
use either contains or the equals method with 'getId', as shown later. This will match any block that includes 'stone' or 'diorit' in its name: withStringBlockFilter().contains("stone") //create new block filter, check if it contains stone
.orStringBlockFilter().contains("diorit") //append new block filter with or and check if it contains diorit  
For non String functions, the method name must be passed when creating the filter. The names can be any method in BlockStateHelper or BlockHelper .
For more complex filters, use the MethodWrapper function FWorld#getWorldScanner(xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.client.api.helpers.world.BlockHelper,java.lang.Object,java.lang.Boolean,?>,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.client.api.helpers.world.BlockStateHelper,java.lang.Object,java.lang.Boolean,?>) .
Depending on the return type of the method, the following parameters must be passed to 'is' or 'test'. There are two methods, because 'is' is a keyword in some languages.  For any number:
  - is(operation, number) with operation = '>', '>=', ' ', ' =', '==', '!=' and the number that should be compared to,
    i.e. is(">=", 8) returns true if the returned number is greater or equal to 8.
For any String:
  - is(method, string) with method = 'EQUALS', 'CONTAINS', 'STARTS_WITH', 'ENDS_WITH', 'MATCHES' and the string is the one to compare the returned value to,
    i.e. is("ENDS_WITH", "ore") checks if the returned string ends with ore (can be used with withBlockFilter("getId")).
For any Boolean:
  - is(val) with val either 'true' or 'false' i.e. is(false) returns true if the returned boolean value is false\n
	Since: 1.6.5 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def withStateFilter(self, method: str) -> "WorldScannerBuilder":
		pass

	@overload
	def andStateFilter(self, method: str) -> "WorldScannerBuilder":
		pass

	@overload
	def orStateFilter(self, method: str) -> "WorldScannerBuilder":
		pass

	@overload
	def notStateFilter(self) -> "WorldScannerBuilder":
		pass

	@overload
	def withBlockFilter(self, method: str) -> "WorldScannerBuilder":
		pass

	@overload
	def andBlockFilter(self, method: str) -> "WorldScannerBuilder":
		pass

	@overload
	def orBlockFilter(self, method: str) -> "WorldScannerBuilder":
		pass

	@overload
	def notBlockFilter(self) -> "WorldScannerBuilder":
		pass

	@overload
	def withStringBlockFilter(self) -> "WorldScannerBuilder":
		pass

	@overload
	def andStringBlockFilter(self) -> "WorldScannerBuilder":
		pass

	@overload
	def orStringBlockFilter(self) -> "WorldScannerBuilder":
		pass

	@overload
	def withStringStateFilter(self) -> "WorldScannerBuilder":
		pass

	@overload
	def andStringStateFilter(self) -> "WorldScannerBuilder":
		pass

	@overload
	def orStringStateFilter(self) -> "WorldScannerBuilder":
		pass

	@overload
	def is_(self, args: List[object]) -> "WorldScannerBuilder":
		pass

	@overload
	def is_(self, methodArgs: List[object], filterArgs: List[object]) -> "WorldScannerBuilder":
		pass

	@overload
	def test(self, args: List[object]) -> "WorldScannerBuilder":
		pass

	@overload
	def test(self, methodArgs: List[object], filterArgs: List[object]) -> "WorldScannerBuilder":
		pass

	@overload
	def equals(self, args: List[str]) -> "WorldScannerBuilder":
		pass

	@overload
	def contains(self, args: List[str]) -> "WorldScannerBuilder":
		pass

	@overload
	def startsWith(self, args: List[str]) -> "WorldScannerBuilder":
		pass

	@overload
	def endsWith(self, args: List[str]) -> "WorldScannerBuilder":
		pass

	@overload
	def matches(self, args: List[str]) -> "WorldScannerBuilder":
		pass

	@overload
	def build(self) -> WorldScanner:
		pass

	pass





from typing import overload
from typing import TypeVar

java_io_File = TypeVar("java_io_File")
File = java_io_File


class FReflection_CombinedVariableClassLoader(ClassLoader):
	"""I know this is probably bad practice, but lets be real, this whole library is bad practice, So I can make it
worse, right? at least this should work better than 'try/catch' 'ing using ClassLoader#loadClass(java.lang.String) to search through every URLClassLoader that FReflection#loadJarFile(java.lang.String) would make, or how I was previously doing it by pre-loading and caching
all the classes to a Map  
This class is a modification to Christian d'Heureuse's JoinClassLoader , under the Apache-2.0 license to change it from a Class array to a Set , to allow for modifications to the ClassLoader contained in the classLoader.\n
	Since: 1.2.8 
	"""

	@overload
	def __init__(self, parent: ClassLoader) -> None:
		pass

	@overload
	def addClassLoader(self, jarPath: File, loader: ClassLoader) -> bool:
		pass

	@overload
	def hasJar(self, path: File) -> bool:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper
from .ItemHelper import ItemHelper
from .ItemStackHelper import ItemStackHelper

net_minecraft_enchantment_Enchantment = TypeVar("net_minecraft_enchantment_Enchantment")
Enchantment = net_minecraft_enchantment_Enchantment


class EnchantmentHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: Enchantment) -> None:
		pass

	@overload
	def __init__(self, base: Enchantment, level: int) -> None:
		pass

	@overload
	def __init__(self, enchantment: str) -> None:
		pass

	@overload
	def getLevel(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the level of this enchantment. 
		"""
		pass

	@overload
	def getMinLevel(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the minimum possible level of this enchantment that one can get in vanilla. 
		"""
		pass

	@overload
	def getMaxLevel(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum possible level of this enchantment that one can get in vanilla. 
		"""
		pass

	@overload
	def getLevelName(self, level: int) -> str:
		"""
		Since: 1.8.4 

		Args:
			level: the level for the name 

		Returns:
			the translated name of this enchantment for the given level. 
		"""
		pass

	@overload
	def getRomanLevelName(self) -> TextHelper:
		"""Because roman numerals only support positive integers in the range of 1 to 3999, this method
will return the arabic numeral for any given level outside that range.\n
		Since: 1.8.4 

		Returns:
			the translated name of this enchantment for the given level in roman numerals. 
		"""
		pass

	@overload
	def getRomanLevelName(self, level: int) -> TextHelper:
		"""Because roman numerals only support positive integers in the range of 1 to 3999, this method
will return the arabic numeral for any given level outside that range.\n
		Since: 1.8.4 

		Args:
			level: the level for the name 

		Returns:
			the translated name of this enchantment for the given level in roman numerals. 
		"""
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of this enchantment. 
		"""
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the id of this enchantment. 
		"""
		pass

	@overload
	def getConflictingEnchantments(self) -> List["EnchantmentHelper"]:
		"""Only accounts for enchantments of the same target type.\n
		Since: 1.8.4 

		Returns:
			a list of all enchantments that conflict with this one. 
		"""
		pass

	@overload
	def getConflictingEnchantments(self, ignoreType: bool) -> List["EnchantmentHelper"]:
		"""
		Since: 1.8.4 

		Args:
			ignoreType: whether to check only enchantments that can be applied to the same target
                  type. 

		Returns:
			a list of all enchantments that conflict with this one. 
		"""
		pass

	@overload
	def getCompatibleEnchantments(self) -> List["EnchantmentHelper"]:
		"""Only accounts for enchantments of the same target type.\n
		Since: 1.8.4 

		Returns:
			a list of all enchantments that can be combined with this one. 
		"""
		pass

	@overload
	def getCompatibleEnchantments(self, ignoreType: bool) -> List["EnchantmentHelper"]:
		"""
		Since: 1.8.4 

		Args:
			ignoreType: whether to check only enchantments that can be applied to the same target
                  type. 

		Returns:
			a list of all enchantments that can be combined with this one. 
		"""
		pass

	@overload
	def getTargetType(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the type of item this enchantment is compatible with. 
		"""
		pass

	@overload
	def getWeight(self) -> int:
		"""The weight of an enchantment is bound to its rarity. The higher the weight, the more likely
it is to be chosen.\n
		Since: 1.8.4 

		Returns:
			the relative probability of this enchantment being applied to an enchanted item
through the enchanting table or a loot table. 
		"""
		pass

	@overload
	def isCursed(self) -> bool:
		"""Curses are enchantments that can't be removed from the item they were applied to. They
usually only have one possible level and can't be upgraded. When combining items with curses
on them, they are transferred like any other enchantment. They can't be obtained through
enchantment tables, but rather from loot chests, fishing or trading with villagers.\n
		Since: 1.8.4 

		Returns:
			'true' if this enchantment is a curse, 'false' otherwise. 
		"""
		pass

	@overload
	def isTreasure(self) -> bool:
		"""Treasures are enchantments that can't be obtained through enchantment tables, but rather from
loot chests, fishing or trading with villagers.\n
		Since: 1.8.4 

		Returns:
			'true' if this enchantment is a treasure, 'false' otherwise. 
		"""
		pass

	@overload
	def canBeApplied(self, item: ItemHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			item: the item to check 

		Returns:
			'true' if this enchantment can be applied to the given item type, 'false' otherwise. 
		"""
		pass

	@overload
	def canBeApplied(self, item: ItemStackHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			item: the item to check 

		Returns:
			'true' if this enchantment can be applied to the given item, 'false' otherwise. 
		"""
		pass

	@overload
	def getAcceptableItems(self) -> List[ItemHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all acceptable item ids for this enchantment. 
		"""
		pass

	@overload
	def isCompatible(self, enchantment: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			enchantment: the enchantment to check 

		Returns:
			'true' if this enchantment is compatible with the given enchantment, 'false' otherwise. 
		"""
		pass

	@overload
	def isCompatible(self, enchantment: "EnchantmentHelper") -> bool:
		"""
		Since: 1.8.4 

		Args:
			enchantment: the enchantment to check 

		Returns:
			'true' if this enchantment is compatible with the given enchantment, 'false' otherwise. 
		"""
		pass

	@overload
	def conflictsWith(self, enchantment: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			enchantment: the enchantment to check 

		Returns:
			'true' if this enchantment conflicts with the given enchantment, 'false' otherwise. 
		"""
		pass

	@overload
	def conflictsWith(self, enchantment: "EnchantmentHelper") -> bool:
		"""
		Since: 1.8.4 

		Args:
			enchantment: the enchantment to check 

		Returns:
			'true' if this enchantment conflicts with the given enchantment, 'false' otherwise. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent
from .BlockDataHelper import BlockDataHelper


class EventInteractBlock(BaseEvent):
	"""
	Since: 1.8.0 
	"""
	offhand: bool
	result: str
	block: BlockDataHelper
	side: int

	@overload
	def __init__(self, offhand: bool, resultStatus: str, block: BlockDataHelper, side: int) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload


class InteractionProxy_Interact:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def setOverride(self, value: bool) -> None:
		pass

	@overload
	def isInteracting(self) -> bool:
		pass

	@overload
	def ensureInteracting(self, cooldown: int) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .BaseHelper import BaseHelper
from .Pos3D import Pos3D
from .HitResultHelper_Block import HitResultHelper_Block
from .HitResultHelper_Entity import HitResultHelper_Entity

net_minecraft_util_hit_HitResult = TypeVar("net_minecraft_util_hit_HitResult")
HitResult = net_minecraft_util_hit_HitResult

T = TypeVar("T")

class HitResultHelper(Generic[T], BaseHelper):
	"""
	Since: 1.9.1 
	"""

	@overload
	def resolve(self, hr: HitResult) -> "HitResultHelper":
		pass

	@overload
	def getPos(self) -> Pos3D:
		pass

	@overload
	def asBlock(self) -> HitResultHelper_Block:
		pass

	@overload
	def asEntity(self) -> HitResultHelper_Entity:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IMixinInteractionEntity import IMixinInteractionEntity

org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_java_lang_Boolean_ = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_java_lang_Boolean_")
CallbackInfoReturnable = org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_java_lang_Boolean_


class MixinInteractionEntity(IMixinInteractionEntity):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_setCanHitOverride(self, value: bool) -> None:
		pass

	@overload
	def overrideCanHit(self, cir: CallbackInfoReturnable) -> None:
		pass

	pass


